@@ -515,7 +515,7 @@ static int do_uninstall(Options *op)
                     existing_installation_is_borked, op->log_file_name);
 
         } else {
-            ui_warn(op, "%s", existing_installation_is_borked);
+            ui_warn(op, existing_installation_is_borked);
         }
     }
     
@@ -618,14 +618,14 @@ static int do_uninstall(Options *op)
             if (!nvrename(op, tmpstr, e->filename)) {
                 ui_warn(op, "Unable to restore file '%s'.", e->filename);
             } else {
-                if (chown(e->filename, e->uid, e->gid)) {
-                    ui_warn(op, "Unable to restore owner (%d) and group "
-                            "(%d) for file '%s' (%s).",
-                            e->uid, e->gid, e->filename, strerror(errno));
+                if (chmod(e->filename, e->mode) == -1) {
+                    ui_warn(op, "Unable to restore permissions %04o for "
+                            "file '%s'.", e->mode, e->filename);
                 } else {
-                    if (chmod(e->filename, e->mode) == -1) {
-                        ui_warn(op, "Unable to restore permissions %04o for "
-                                "file '%s'.", e->mode, e->filename);
+                    if (chown(e->filename, e->uid, e->gid)) {
+                        ui_warn(op, "Unable to restore owner (%d) and group "
+                                "(%d) for file '%s' (%s).",
+                                e->uid, e->gid, e->filename, strerror(errno));
                     }
                 }
             }
@@ -659,7 +659,7 @@ static BackupInfo *read_backup_log_file(Options *op)
 {
     struct stat stat_buf;
     char *buf, *c, *line, *filename;
-    int fd, num, length, line_num = 0;
+    int fd, num, line_num = 0;
     float percent;
     
     BackupLogEntry *e;
@@ -698,9 +698,7 @@ static BackupInfo *read_backup_log_file(Options *op)
 
     /* map the file */
 
-    length = stat_buf.st_size;
-
-    buf = mmap(0, length, PROT_READ, MAP_FILE | MAP_SHARED, fd, 0);
+    buf = mmap(0, stat_buf.st_size, PROT_READ, MAP_FILE | MAP_SHARED, fd, 0);
     if (!buf) {
         ui_error(op, "Unable to mmap file '%s' (%s).", strerror(errno));
         return NULL;
@@ -710,13 +708,13 @@ static BackupInfo *read_backup_log_file(Options *op)
 
     b = nvalloc(sizeof(BackupInfo));
 
-    b->version = get_next_line(buf, &c, buf, length);
+    b->version = get_next_line(buf, &c);
     if (!b->version || !c) goto parse_error;
     
     percent = (float) (c - buf) / (float) stat_buf.st_size;
     ui_status_update(op, percent, NULL);
 
-    b->description = get_next_line(c, &c, buf, length);
+    b->description = get_next_line(c, &c);
     if (!b->description || !c) goto parse_error;
 
     b->n = 0;
@@ -730,7 +728,7 @@ static BackupInfo *read_backup_log_file(Options *op)
         
         /* read and parse the next line */
 
-        line = get_next_line(c, &c, buf, length);
+        line = get_next_line(c, &c);
         if (!line) break;
 
         if (!parse_first_line(line, &num, &filename)) goto parse_error;
@@ -751,8 +749,7 @@ static BackupInfo *read_backup_log_file(Options *op)
         switch(e->num) {
 
         case INSTALLED_FILE:
-            line = get_next_line(c, &c, buf, length);
-            if (line == NULL) goto parse_error;
+            if ((line = get_next_line(c, &c)) == NULL) goto parse_error;
             line_num++;
 
             if (!parse_crc(line, &e->crc)) goto parse_error;
@@ -761,8 +758,7 @@ static BackupInfo *read_backup_log_file(Options *op)
             break;
 
         case INSTALLED_SYMLINK:
-            line = get_next_line(c, &c, buf, length);
-            if (line == NULL) goto parse_error;
+            if ((line = get_next_line(c, &c)) == NULL) goto parse_error;
             line_num++;
             
             e->target = line;
@@ -770,14 +766,12 @@ static BackupInfo *read_backup_log_file(Options *op)
             break;
             
         case BACKED_UP_SYMLINK:
-            line = get_next_line(c, &c, buf, length);
-            if (line == NULL) goto parse_error;
+            if ((line = get_next_line(c, &c)) == NULL) goto parse_error;
             line_num++;
             
             e->target = line;
 
-            line = get_next_line(c, &c, buf, length);
-            if (line == NULL) goto parse_error;
+            if ((line = get_next_line(c, &c)) == NULL) goto parse_error;
             line_num++;
 
             if (!parse_mode_uid_gid(line, &e->mode, &e->uid, &e->gid))
@@ -789,8 +783,7 @@ static BackupInfo *read_backup_log_file(Options *op)
         default:
             if (num < BACKED_UP_FILE_NUM) goto parse_error;
             
-            line = get_next_line(c, &c, buf, length);
-            if (line == NULL) goto parse_error;
+            if ((line = get_next_line(c, &c)) == NULL) goto parse_error;
             line_num++;
 
             if (!parse_crc_mode_uid_gid(line, &e->crc, &e->mode,
@@ -987,25 +980,23 @@ char *get_installed_driver_version_and_descr(Options *op, int *major,
 {
     struct stat stat_buf;
     char *c, *version = NULL, *descr = NULL, *buf = NULL;
-    int length, fd = -1;
+    int fd = -1;
 
     if ((fd = open(BACKUP_LOG, O_RDONLY)) == -1) goto done;
     
     if (fstat(fd, &stat_buf) == -1) goto done;
     
     /* map the file */
-
-    length = stat_buf.st_size;
     
-    buf = mmap(0, length, PROT_READ, MAP_FILE | MAP_SHARED, fd, 0);
+    buf = mmap(0, stat_buf.st_size, PROT_READ, MAP_FILE | MAP_SHARED, fd, 0);
     if (!buf) goto done;
     
-    version = get_next_line(buf, &c, buf, length);
+    version = get_next_line(buf, &c);
     if (!version) goto done;
 
     if (!nvid_version(version, major, minor, patch)) goto done;
     
-    descr = get_next_line(c, NULL, buf, length);
+    descr = get_next_line(c, NULL);
 
  done:
     if (version) free(version);
