@@ -47,26 +47,14 @@
 #include "kernel.h"
 
 
-static void find_conflicting_xfree86_libraries(Options *,
-                                               const char *,
-                                               FileList *);
-
-static void find_conflicting_xfree86_libraries_fullpath(Options *op,
-                                                        const char *,
-                                                        FileList *l);
-
-static void find_conflicting_opengl_libraries(Options *,
-                                              const char *,
-                                              FileList *);
-
-static void find_conflicting_kernel_modules(Options *op,
-                                            Package *p,
-                                            FileList *l);
 
 static void find_existing_files(Package *p, FileList *l, unsigned int);
+static void find_conflicting_kernel_modules(Options *op,
+                                            Package *p, FileList *l);
 
 static void add_command (CommandList *c, int cmd, ...);
 
+static void find_matches (const char*, const char*, FileList*, const int);
 static void add_file_to_list(const char*, const char*, FileList*);
 
 static void append_to_rpm_file_list(Options *op, Command *c);
@@ -99,77 +87,41 @@ CommandList *build_command_list(Options *op, Package *p)
     l = (FileList *) nvalloc(sizeof(FileList));
     c = (CommandList *) nvalloc(sizeof(CommandList));
 
-    /* find any possibly conflicting libraries and/or modules */
+    /* find any possible conflicting libraries */
     
     if (!op->kernel_module_only) {
-        /*
-         * Note that searching the various paths may produce duplicate
-         * entries for conflicting files; this is OK because we will take
-         * care of these duplicates in condense_file_list().
-         */
 
-        ui_status_begin(op, "Searching for conflicting X files:", "Searching");
-
-        ui_status_update(op, 0.16f, DEFAULT_X_PREFIX);
-        find_conflicting_xfree86_libraries(op, DEFAULT_X_PREFIX, l);
-        ui_status_update(op, 0.32f, XORG7_DEFAULT_X_PREFIX);
-        find_conflicting_xfree86_libraries(op, XORG7_DEFAULT_X_PREFIX, l);
-        ui_status_update(op, 0.48f, op->x_prefix);
-        find_conflicting_xfree86_libraries(op, op->x_prefix, l);
-
-        ui_status_update(op, 0.64f, op->x_module_path);
-        find_conflicting_xfree86_libraries_fullpath(op, op->x_module_path, l);
-        ui_status_update(op, 0.80f, op->x_library_path);
-        find_conflicting_xfree86_libraries_fullpath(op, op->x_library_path, l);
-
-        ui_status_end(op, "done.");
-
-        ui_status_begin(op, "Searching for conflicting OpenGL files:", "Searching");
-
-        ui_status_update(op, 0.20f, DEFAULT_X_PREFIX);
-        find_conflicting_opengl_libraries(op, DEFAULT_X_PREFIX, l);
-        ui_status_update(op, 0.40f, op->x_prefix);
-        find_conflicting_opengl_libraries(op, op->x_prefix, l);
-        ui_status_update(op, 0.60f, DEFAULT_OPENGL_PREFIX);
-        find_conflicting_opengl_libraries(op, DEFAULT_OPENGL_PREFIX, l);
-        ui_status_update(op, 0.80f, op->opengl_prefix);
-        find_conflicting_opengl_libraries(op, op->opengl_prefix, l);
-
-        ui_status_end(op, "done.");
+        find_conflicting_xfree86_libraries
+            (op, DEFAULT_XFREE86_INSTALLATION_PREFIX, l);
+    
+        if (strcmp(DEFAULT_XFREE86_INSTALLATION_PREFIX,
+                   op->xfree86_prefix) != 0)
+            find_conflicting_xfree86_libraries(op, op->xfree86_prefix, l);
+    
+        find_conflicting_opengl_libraries
+            (op, DEFAULT_OPENGL_INSTALLATION_PREFIX, l);
+    
+        if (strcmp(DEFAULT_OPENGL_INSTALLATION_PREFIX, op->opengl_prefix) != 0)
+            find_conflicting_opengl_libraries(op, op->opengl_prefix, l);
 
 #if defined(NV_X86_64)
-        if (op->compat32_chroot != NULL) {
-            char *prefix;
-
-            ui_status_begin(op, "Searching for conflicting compat32 files:", "Searching");
-
-            prefix = nvstrcat(op->compat32_chroot, DEFAULT_X_PREFIX, NULL);
-            ui_status_update(op, 0.20f, prefix);
+        if (op->compat32_prefix != NULL) {
+            char *prefix = nvstrcat(op->compat32_prefix,
+                                    DEFAULT_OPENGL_INSTALLATION_PREFIX, NULL);
             find_conflicting_opengl_libraries(op, prefix, l);
             nvfree(prefix);
 
-            prefix = nvstrcat(op->compat32_chroot, op->x_prefix, NULL);
-            ui_status_update(op, 0.40f, prefix);
-            find_conflicting_opengl_libraries(op, prefix, l);
-            nvfree(prefix);
-
-            prefix = nvstrcat(op->compat32_chroot, DEFAULT_OPENGL_PREFIX, NULL);
-            ui_status_update(op, 0.60f, prefix);
-            find_conflicting_opengl_libraries(op, prefix, l);
-            nvfree(prefix);
-
-            prefix = nvstrcat(op->compat32_chroot, op->compat32_prefix, NULL);
-            ui_status_update(op, 0.80f, prefix);
-            find_conflicting_opengl_libraries(op, prefix, l);
-            nvfree(prefix);
-
-            ui_status_end(op, "done.");
+            if (strcmp(DEFAULT_OPENGL_INSTALLATION_PREFIX,
+                op->opengl_prefix) != 0) {
+                prefix = nvstrcat(op->compat32_prefix, op->opengl_prefix, NULL);
+                find_conflicting_opengl_libraries(op, prefix, l);
+                nvfree(prefix);
+            }
         }
 #endif /* NV_X86_64 */
     }
     
-    if (!op->no_kernel_module)
-        find_conflicting_kernel_modules(op, p, l);
+    find_conflicting_kernel_modules(op, p, l);
     
     /*
      * find any existing files that clash with what we're going to
@@ -215,24 +167,14 @@ CommandList *build_command_list(Options *op, Package *p)
         }
 
         /*
-         * delete the temporary libGL.la and .desktop files generated
-         * based on templates earlier.
+         * delete the temporary libGL.la file generated based on
+         * the template earlier.
          */
 
-        if ((p->entries[i].flags & FILE_TYPE_LIBGL_LA) ||
-                (p->entries[i].flags & FILE_TYPE_DOT_DESKTOP)) {
+        if (p->entries[i].flags & FILE_TYPE_LIBGL_LA) {
             add_command(c, DELETE_CMD,
                         p->entries[i].file);
         }
-        
-        if (op->selinux_enabled && 
-            ((p->entries[i].flags & FILE_TYPE_SHARED_LIB) ||
-             (p->entries[i].flags & FILE_TYPE_XMODULE_SHARED_LIB))) {
-            tmp = nvstrcat(op->utils[CHCON], " -t ", op->selinux_chcon_type,
-                           " ", p->entries[i].dst, NULL);
-            add_command(c, RUN_CMD, tmp);
-            nvfree(tmp);
-        }
     }
 
 
@@ -453,26 +395,19 @@ int execute_command_list(Options *op, CommandList *c,
 typedef struct {
     const char *name;
     int len;
-} ConflictingFileInfo;
-
-static void find_conflicting_files(Options *op,
-                                   char *path,
-                                   ConflictingFileInfo *files,
-                                   FileList *l);
+} ConflictingLibInfo;
 
 static void find_conflicting_libraries(Options *op,
                                        const char *prefix,
-                                       ConflictingFileInfo *libs,
+                                       ConflictingLibInfo *libs,
                                        FileList *l);
 
-static ConflictingFileInfo __xfree86_libs[] = {
+static ConflictingLibInfo __xfree86_libs[] = {
     { "libGLcore.",     10 /* strlen("libGLcore.") */    },
     { "libGL.",         6  /* strlen("libGL.") */        },
     { "libGLwrapper.",  13 /* strlen("libGLwrapper.") */ },
     { "libglx.",        7  /* strlen("libglx.") */       },
-    { "libXvMCNVIDIA",  13 /* strlen("libXvMCNVIDIA") */ },
-    { "libnvidia-cfg.", 14 /* strlen("libnvidia-cfg.") */ },
-    { "nvidia_drv.",    11 /* strlen("nvidia_drv.") */   },
+    { "libXvMCNVIDIA",  14 /* strlen("libXvMCNVIDIA") */ },
     { NULL, 0 }
 };
 
@@ -482,40 +417,19 @@ static ConflictingFileInfo __xfree86_libs[] = {
  * libdirs.
  */
 
-static void find_conflicting_xfree86_libraries(Options *op,
-                                               const char *xprefix,
-                                               FileList *l)
+void find_conflicting_xfree86_libraries(Options *op,
+                                        const char *xprefix, FileList *l)
 {
     find_conflicting_libraries(op, xprefix, __xfree86_libs, l);
 
 } /* find_conflicting_xfree86_libraries() */
 
 
-
-/*
- * find_conflicting_xfree86_libraries_fullpath() - same as
- * find_conflicting_xfree86_libraries, but bypasses the
- * find_conflicting_libraries step, which appends "lib", "lib64", and
- * "lib32" to the path name.  Use this when you have the fullpath that
- * you want searched.
- */
-
-static void find_conflicting_xfree86_libraries_fullpath(Options *op,
-                                                        const char *path,
-                                                        FileList *l)
-{
-    find_conflicting_files(op, (char *) path, __xfree86_libs, l);
-    
-} /* find_conflicting_xfree86_libraries_fullpath() */
-
-
-
-static ConflictingFileInfo __opengl_libs[] = {
+static ConflictingLibInfo __opengl_libs[] = {
     { "libGLcore.",     10 /* strlen("libGLcore.") */     },
     { "libGL.",         6  /* strlen("libGL.") */         },
     { "libnvidia-tls.", 14 /* strlen("libnvidia-tls.") */ },
     { "libGLwrapper.",  13 /* strlen("libGLwrapper.") */  },
-    { "libnvidia-cfg.", 14 /* strlen("libnvidia-cfg.") */ },
     { NULL, 0 }
 };
 
@@ -525,9 +439,8 @@ static ConflictingFileInfo __opengl_libs[] = {
  * libdirs.
  */
 
-static void find_conflicting_opengl_libraries(Options *op,
-                                              const char *glprefix,
-                                              FileList *l)
+void find_conflicting_opengl_libraries(Options *op,
+                                       const char *glprefix, FileList *l)
 {
     find_conflicting_libraries(op, glprefix, __opengl_libs, l);
 
@@ -538,44 +451,41 @@ static void find_conflicting_opengl_libraries(Options *op,
 /*
  * find_conflicting_kernel_modules() - search for conflicting kernel
  * modules under the kernel module installation prefix.
+ *
+ * XXX rather than use a fixed list of prefixes, maybe we should scan for the
+ * kernel module name anywhere under /lib/modules/`uname -r`/ ?
  */
 
 static void find_conflicting_kernel_modules(Options *op,
                                             Package *p, FileList *l)
 {
     int i, n = 0;
-    ConflictingFileInfo files[2];
-    char *paths[3];
+    char *prefixes[5];
     char *tmp = get_kernel_name(op);
 
-    files[1].name = NULL;
-    files[1].len = 0;
-    paths[0] = op->kernel_module_installation_path;
+    prefixes[0] = op->kernel_module_installation_path;
 
     if (tmp) {
-        paths[1] = nvstrcat("/lib/modules/", tmp, NULL);
-        paths[2] = NULL;
+        prefixes[1] = nvstrcat("/lib/modules/", tmp, "/kernel/drivers/video", NULL);
+        prefixes[2] = nvstrcat("/lib/modules/", tmp, "/kernel/drivers/char", NULL);
+        prefixes[3] = nvstrcat("/lib/modules/", tmp, "/video", NULL);
+        prefixes[4] = NULL;
     } else {
-        paths[1] = NULL;
+        prefixes[1] = NULL;
     }
     
-    for (i = 0; paths[i]; i++) {
+    /* look for all the conflicting module names in all the possible prefixes */
+    
+    for (i = 0; prefixes[i]; i++) {
         for (n = 0; p->bad_module_filenames[n]; n++) {
-            /*
-             * Recursively search for this conflicting kernel module
-             * relative to the current prefix.
-             */
-            files[0].name = p->bad_module_filenames[n];
-            files[0].len = strlen(files[0].name);
-
-            find_conflicting_files(op, paths[i], files, l);
+            find_matches(prefixes[i], p->bad_module_filenames[n], l, TRUE);
         }
     }
 
-    /* free any paths we nvstrcat()'d above  */
+    /* free any prefixes we nvstrcat()ed above  */
 
-    for (i = 1; paths[i]; i++) {
-        nvfree(paths[i]);
+    for (i = 1; prefixes[i]; i++) {
+        nvfree(prefixes[i]);
     }
 
 } /* find_conflicting_kernel_modules() */
@@ -606,23 +516,24 @@ static void find_existing_files(Package *p, FileList *l, unsigned int flag)
 
 
 /*
- * find_conflicting_files() - search for any conflicting
- * files in all the specified paths within the hierarchy under
+ * find_conflicting_libraries() - search for any conflicting
+ * libraries in all relevant libdirs within the hierarchy under
  * the given prefix.
  */
 
-static void find_conflicting_files(Options *op,
-                                   char *path,
-                                   ConflictingFileInfo *files,
-                                   FileList *l)
+static void find_conflicting_libraries(Options *op,
+                                       const char *prefix,
+                                       ConflictingLibInfo *libs,
+                                       FileList *l)
 {
     int i;
-    char *paths[2];
+    char *paths[3];
     FTS *fts;
     FTSENT *ent;
 
-    paths[0] = path; /* search root */
-    paths[1] = NULL;
+    paths[0] = nvstrcat(prefix, "/", "lib", NULL);
+    paths[1] = nvstrcat(prefix, "/", "lib64", NULL);
+    paths[2] = NULL;
 
     fts = fts_open(paths, FTS_LOGICAL | FTS_NOSTAT, NULL);
     if (!fts) return;
@@ -631,8 +542,8 @@ static void find_conflicting_files(Options *op,
         switch (ent->fts_info) {
         case FTS_F:
         case FTS_SLNONE:
-            for (i = 0; files[i].name; i++) {
-                if (!strncmp(ent->fts_name, files[i].name, files[i].len))
+            for (i = 0; libs[i].name; i++) {
+                if (!strncmp(ent->fts_name, libs[i].name, libs[i].len))
                     add_file_to_list(NULL, ent->fts_path, l);
             }
             break;
@@ -657,54 +568,7 @@ static void find_conflicting_files(Options *op,
 
     fts_close(fts);
 
-} /* find_conflicting_files() */
-
-
-
-
-/*
- * find_conflicting_libraries() - search for any conflicting
- * libraries in all relevant libdirs within the hierarchy under
- * the given prefix.
- */
-
-static void find_conflicting_libraries(Options *op,
-                                       const char *prefix,
-                                       ConflictingFileInfo *files,
-                                       FileList *l)
-{
-    int i, j;
-    char *paths[4];
-
-    paths[0] = nvstrcat(prefix, "/", "lib", NULL);
-    paths[1] = nvstrcat(prefix, "/", "lib64", NULL);
-    paths[2] = nvstrcat(prefix, "/", "lib32", NULL);
-    paths[3] = NULL;
-
-    for (i = 0; paths[i]; i++) {
-        for (j = 0; (j < 3) && paths[i]; j++) {
-            /*
-             * XXX Check if any one of the 'paths' entries really
-             * is a symbolic link pointing to one of the other
-             * entries. The logic could be made smarter, since it's
-             * unlikely that ../lib32 would be a symbolic link to
-             * ../lib64 or vice versa.
-             */
-            if (!paths[j] || (i == j)) continue;
-
-            if (is_symbolic_link_to(paths[i], paths[j])) {
-                ui_expert(op, "The conflicting library search path "
-                          "'%s' is a symbolic link to the library "
-                          "search path '%s'; skipping '%s'.",
-                          paths[i], paths[j], paths[i]);
-                free(paths[i]); paths[i] = NULL;
-            }
-        }
-
-        if (paths[i]) find_conflicting_files(op, paths[i], files, l);
-    }
-
-    for (i = 0; i < 3; i++)
+    for (i = 0; paths[i]; i++)
         nvfree(paths[i]);
 
 } /* find_conflicting_libraries() */
@@ -721,40 +585,10 @@ void condense_file_list(FileList *l)
     char **s = NULL;
     int n = 0, i, j, match;
 
-    struct stat stat_buf, *stat_bufs;
-
-    /* allocate enough space in our temporary 'stat' array */
-
-    if (l->num) {
-        stat_bufs  = nvalloc(sizeof(struct stat) * l->num);
-    } else {
-        stat_bufs  = NULL;
-    }
-    
-    /*
-     * walk through our original (uncondensed) list of files and move
-     * unique files to a new (condensed) list.  For each file in the
-     * original list, get the filesystem information for the file, and
-     * then compare that to the filesystem information for all the
-     * files in the new list.  If the file from the original list does
-     * not match any file in the new list, add it to the new list.
-     */
-
     for (i = 0; i < l->num; i++) {
         match = FALSE;
-
-        if (lstat(l->filename[i], &stat_buf) == -1)
-            continue;
-        
         for (j = 0; j < n; j++) {
-
-            /*
-             * determine if the two files are the same by comparing
-             * device and inode
-             */
-
-            if ((stat_buf.st_dev == stat_bufs[j].st_dev) &&
-                (stat_buf.st_ino == stat_bufs[j].st_ino)) {
+            if (strcmp(l->filename[i], s[j]) == 0) {
                 match = TRUE;
                 break;
             }
@@ -763,13 +597,10 @@ void condense_file_list(FileList *l)
         if (!match) {
             s = (char **) nvrealloc(s, sizeof(char *) * (n + 1));
             s[n] = nvstrdup(l->filename[i]);
-            stat_bufs[n] = stat_buf;
             n++;
         }
     }
     
-    if (stat_bufs) nvfree((void *)stat_bufs);
-
     for (i = 0; i < l->num; i++) free(l->filename[i]);
     free(l->filename);
 
@@ -838,6 +669,50 @@ static void add_command(CommandList *c, int cmd, ...)
 
 
 
+/*
+ * find_matches() - given a directory, a filename, and an existing
+ * FileList data structure, open the specified directory, and look for
+ * any entries that match the filename.
+ *
+ * If the parameter 'exact' is TRUE, then the filenames must match
+ * exactly.  If 'exact' is FALSE, then only the beginning of the
+ * directory entry name must match the filename in question.
+ *
+ * This could alternatively be implemented using glob(3).
+ */
+
+static void find_matches(const char *directory, const char *filename,
+                         FileList *l, const int exact)
+{
+    struct stat stat_buf;
+    struct dirent *ent;
+    int len;
+    DIR *dir;
+    
+    if (lstat(directory, &stat_buf) == -1) return;
+    if (S_ISDIR(stat_buf.st_mode) == 0) return;
+    if ((dir = opendir(directory)) == NULL) return;
+
+    len = strlen(filename);
+
+    while ((ent = readdir(dir)) != NULL) {
+        if (exact) {
+            if (strcmp(ent->d_name, filename) == 0) {
+                add_file_to_list(directory, ent->d_name, l);
+            }
+        } else {
+            if (strncmp(ent->d_name, filename, len) == 0) {
+                add_file_to_list(directory, ent->d_name, l);
+            }
+        }
+    }
+    
+    closedir (dir); 
+    
+} /* find_matches() */
+
+
+
 /*
  * add_file_to_list() - concatenate the given directory and filename,
  * appending to the FileList structure.  If the 'directory' parameter
