@@ -47,12 +47,6 @@
 #include "misc.h"
 #include "precompiled.h"
 
-
-static char *get_xdg_data_dir(void);
-static int   get_x_library_path(Options *op);
-static int   get_x_module_path(Options *op);
-
-
 /*
  * remove_directory() - recursively delete a direcotry (`rm -rf`)
  */
@@ -484,11 +478,8 @@ void select_tls_class(Options *op, Package *p)
 
 int set_destinations(Options *op, Package *p)
 {
-    char *name, *s;
-    char *prefix, *dir, *path;
-    char *xdg_data_dir;
+    char *prefix, *path, *name;
     int i;
-    s = NULL;
     
     for (i = 0; i < p->num_entries; i++) {
 
@@ -504,58 +495,25 @@ int set_destinations(Options *op, Package *p)
             
         case FILE_TYPE_OPENGL_LIB:
         case FILE_TYPE_OPENGL_SYMLINK:
-            if (p->entries[i].flags & FILE_CLASS_COMPAT32) {
-                prefix = op->compat32_prefix;
-                dir = op->compat32_libdir;
-            } else {
-                prefix = op->opengl_prefix;
-                dir = op->opengl_libdir;
-            }
-            path = "";
+            prefix = op->opengl_prefix;
+            path = p->entries[i].path;
             break;
             
-        case FILE_TYPE_XLIB_SHARED_LIB:
-        case FILE_TYPE_XLIB_STATIC_LIB:
-        case FILE_TYPE_XLIB_SYMLINK:
-            prefix = op->x_library_path;
-            dir = path = "";
-            break;
-
-        case FILE_TYPE_XMODULE_SHARED_LIB:
-        case FILE_TYPE_XMODULE_SYMLINK:
-            prefix = op->x_module_path;
-            dir = "";
+        case FILE_TYPE_XFREE86_LIB:
+        case FILE_TYPE_XFREE86_SYMLINK:
+            prefix = op->xfree86_prefix;
             path = p->entries[i].path;
             break;
 
         case FILE_TYPE_TLS_LIB:
         case FILE_TYPE_TLS_SYMLINK:
-            if (p->entries[i].flags & FILE_CLASS_COMPAT32) {
-                prefix = op->compat32_prefix;
-                dir = op->compat32_libdir;
-            } else {
-                prefix = op->opengl_prefix;
-                dir = op->opengl_libdir;
-            }
+            prefix = op->opengl_prefix;
             path = p->entries[i].path;
             break;
 
-        case FILE_TYPE_UTILITY_LIB:
-        case FILE_TYPE_UTILITY_SYMLINK:
-            prefix = op->utility_prefix;
-            dir = op->utility_libdir;
-            path = "";
-            break;
-
         case FILE_TYPE_LIBGL_LA:
-            if (p->entries[i].flags & FILE_CLASS_COMPAT32) {
-                prefix = op->compat32_prefix;
-                dir = op->compat32_libdir;
-            } else {
-                prefix = op->opengl_prefix;
-                dir = op->opengl_libdir;
-            }
-            path = "";
+            prefix = op->opengl_prefix;
+            path = p->entries[i].path;
             break;
 
             /*
@@ -567,44 +525,22 @@ int set_destinations(Options *op, Package *p)
 
         case FILE_TYPE_OPENGL_HEADER:
             prefix = op->opengl_prefix;
-            dir = op->opengl_incdir;
+            path = OPENGL_HEADER_DST_PATH;
+            break;
+            
+        case FILE_TYPE_DOCUMENTATION:
+            prefix = op->opengl_prefix;
             path = p->entries[i].path;
             break;
         
         case FILE_TYPE_INSTALLER_BINARY:
-            prefix = op->utility_prefix;
-            dir = op->utility_bindir;
-            path = "";
+            prefix = op->installer_prefix;
+            path = INSTALLER_BINARY_DST_PATH;
             break;
             
-        case FILE_TYPE_DOCUMENTATION:
-            prefix = op->documentation_prefix;
-            dir = op->documentation_docdir;
-            path = p->entries[i].path;
-            break;
-
-        case FILE_TYPE_MANPAGE:
-            prefix = op->documentation_prefix;
-            dir = op->documentation_mandir;
-            path = p->entries[i].path;
-            break;
-
         case FILE_TYPE_UTILITY_BINARY:
             prefix = op->utility_prefix;
-            dir = op->utility_bindir;
-            path = "";
-            break;
-
-        case FILE_TYPE_DOT_DESKTOP:
-            xdg_data_dir = get_xdg_data_dir();
-            if (xdg_data_dir) {
-                prefix = xdg_data_dir;
-                dir = nvstrdup("applications");
-            } else {
-                prefix = op->utility_prefix;
-                dir = op->dot_desktopdir;
-            }
-            path = "";
+            path = UTILITY_BINARY_DST_PATH;
             break;
 
         case FILE_TYPE_KERNEL_MODULE:
@@ -626,20 +562,14 @@ int set_destinations(Options *op, Package *p)
             p->entries[i].dst = NULL;
             continue;
         }
-
-        if ((prefix == NULL) || (dir == NULL) || (path == NULL)) {
-            p->entries[i].dst = NULL;
-            continue;
-        }
         
         name = p->entries[i].name;
 
-        p->entries[i].dst = nvstrcat(prefix, "/", dir, "/", path, "/", name, NULL);
-        collapse_multiple_slashes(p->entries[i].dst);
+        p->entries[i].dst = nvstrcat(prefix, "/", path, "/", name, NULL);
 
 #if defined(NV_X86_64)
         if ((p->entries[i].flags & FILE_CLASS_COMPAT32) &&
-            (op->compat32_chroot != NULL)) {
+            (op->compat32_prefix != NULL)) {
 
             /*
              * prepend an additional prefix; this is currently only
@@ -648,7 +578,7 @@ int set_destinations(Options *op, Package *p)
              */
 
             char *dst = p->entries[i].dst;
-            p->entries[i].dst = nvstrcat(op->compat32_chroot, dst, NULL);
+            p->entries[i].dst = nvstrcat(op->compat32_prefix, dst, NULL);
 
             nvfree(dst);
         }
@@ -670,7 +600,7 @@ int set_destinations(Options *op, Package *p)
 int get_license_acceptance(Options *op)
 {
     struct stat buf;
-    char *text, *tmp;
+    char *text;
     int fd;
 
     /* trivial accept if the user accepted on the command line */
@@ -688,18 +618,8 @@ int get_license_acceptance(Options *op)
                               MAP_FILE|MAP_SHARED,
                               fd, 0x0)) == (char *) -1) goto failed;
     
-    /*
-     * the mmap'ed license file may not be NULL terminated, so copy it
-     * into a temporary buffer and explicity NULL terminate the string
-     */
-
-    tmp = nvalloc(buf.st_size + 1);
-    memcpy(tmp, text, buf.st_size);
-    tmp[buf.st_size] = '\0';
-    
-    if (!ui_display_license(op, tmp)) {
+    if (!ui_display_license(op, text)) {
         ui_message(op, "License not accepted.  Aborting installation.");
-        nvfree(tmp);
         munmap(text, buf.st_size);
         close(fd);
         return FALSE;
@@ -707,7 +627,6 @@ int get_license_acceptance(Options *op)
     
     ui_log(op, "License accepted.");
     
-    nvfree(tmp);
     munmap(text, buf.st_size);
     close(fd);
     
@@ -734,55 +653,18 @@ int get_prefixes (Options *op)
     char *ret;
  
     if (op->expert) {
-        ret = ui_get_input(op, op->x_prefix,
+        ret = ui_get_input(op, op->xfree86_prefix,
                            "X installation prefix (only under "
                            "rare circumstances should this be changed "
                            "from the default)");
         if (ret && ret[0]) {
-            op->x_prefix = ret; 
-            if (!confirm_path(op, op->x_prefix)) return FALSE;
+            op->xfree86_prefix = ret; 
+            if (!confirm_path(op, op->xfree86_prefix)) return FALSE;
         }
     }
 
-    remove_trailing_slashes(op->x_prefix);
-    ui_expert(op, "X installation prefix is: '%s'", op->x_prefix);
-    
-    /*
-     * assign the X module and library paths; this must be done
-     * after the default prefixes/paths are assigned.
-     */
-
-    if (!get_x_library_path(op) || !get_x_module_path(op)) {
-        return FALSE;
-    }
-
-    if (op->expert) {
-        ret = ui_get_input(op, op->x_library_path,
-                           "X library installation path (only under "
-                           "rare circumstances should this be changed "
-                           "from the default)");
-        if (ret && ret[0]) {
-            op->x_library_path = ret; 
-            if (!confirm_path(op, op->x_library_path)) return FALSE;
-        }
-    }
-
-    remove_trailing_slashes(op->x_library_path);
-    ui_expert(op, "X library installation path is: '%s'", op->x_library_path);
-
-    if (op->expert) {
-        ret = ui_get_input(op, op->x_module_path,
-                           "X module installation path (only under "
-                           "rare circumstances should this be changed "
-                           "from the default)");
-        if (ret && ret[0]) {
-            op->x_module_path = ret; 
-            if (!confirm_path(op, op->x_module_path)) return FALSE;
-        }
-    }
-
-    remove_trailing_slashes(op->x_module_path);
-    ui_expert(op, "X module installation path is: '%s'", op->x_module_path);
+    remove_trailing_slashes(op->xfree86_prefix);
+    ui_expert(op, "X installation prefix is: '%s'", op->xfree86_prefix);
         
     if (op->expert) {
         ret = ui_get_input(op, op->opengl_prefix,
@@ -798,57 +680,10 @@ int get_prefixes (Options *op)
     remove_trailing_slashes(op->opengl_prefix);
     ui_expert(op, "OpenGL installation prefix is: '%s'", op->opengl_prefix);
 
-
-    if (op->expert) {
-        ret = ui_get_input(op, op->documentation_prefix,
-                           "Documentation installation prefix (only under "
-                           "rare circumstances should this be changed "
-                           "from the default)");
-        if (ret && ret[0]) {
-            op->documentation_prefix = ret;
-            if (!confirm_path(op, op->documentation_prefix)) return FALSE;
-        }
-    }
-
-    remove_trailing_slashes(op->documentation_prefix);
-    ui_expert(op, "Documentation installation prefix is: '%s'", op->documentation_prefix);
-
-
-    if (op->expert) {
-        ret = ui_get_input(op, op->utility_prefix,
-                           "Utility installation prefix (only under "
-                           "rare circumstances should this be changed "
-                           "from the default)");
-        if (ret && ret[0]) {
-            op->utility_prefix = ret;
-            if (!confirm_path(op, op->utility_prefix)) return FALSE;
-        }
-    }
-
-    remove_trailing_slashes(op->utility_prefix);
-    ui_expert(op, "Utility installation prefix is: '%s'", op->utility_prefix);
-
 #if defined(NV_X86_64)
-    if (op->expert) {
-        ret = ui_get_input(op, op->compat32_chroot,
-                           "Compat32 installation chroot (only under "
-                           "rare circumstances should this be "
-                           "changed from the default)");
-        if (ret && ret[0]) {
-            op->compat32_chroot = ret;
-            if (!confirm_path(op, op->compat32_chroot)) return FALSE;
-        }
-    }
-
-    remove_trailing_slashes(op->compat32_chroot);
-    ui_expert(op, "Compat32 installation chroot is: '%s'",
-              op->compat32_chroot);
-
     if (op->expert) {
         ret = ui_get_input(op, op->compat32_prefix,
-                           "Compat32 installation prefix (only under "
-                           "rare circumstances should this be "
-                           "changed from the default)");
+                           "Compat32 installation prefix");
         if (ret && ret[0]) {
             op->compat32_prefix = ret;
             if (!confirm_path(op, op->compat32_prefix)) return FALSE;
@@ -860,6 +695,19 @@ int get_prefixes (Options *op)
               op->compat32_prefix);
 #endif /* NV_X86_64 */
 
+    if (op->expert) {
+        ret = ui_get_input(op, op->installer_prefix,
+                           "Installer installation prefix");
+        if (ret && ret[0]) {
+            op->installer_prefix = ret;
+            if (!confirm_path(op, op->installer_prefix)) return FALSE;
+        }
+    }
+    
+    remove_trailing_slashes(op->installer_prefix);
+    ui_expert(op, "Installer installation prefix is: '%s'",
+              op->installer_prefix);
+    
     return TRUE;
     
 } /* get_prefixes() */
@@ -1560,157 +1408,6 @@ static char *nv_strreplace(char *src, char *orig, char *replace)
 
 
 
-/*
- * process_template_file() - copy the specified template file to
- * a temporary file, replacing specified tokens with specified
- * replacement strings.  Return the temporary file's path to the
- * caller or NULL, if an error occurs.
- */
-
-char *process_template_file(Options *op, PackageEntry *pe,
-                            char **tokens, char **replacements)
-{
-    int failed, src_fd, dst_fd, len;
-    struct stat stat_buf;
-    char *src, *dst, *tmp, *tmp0, *tmpfile = NULL;
-    char *token, *replacement;
-
-    failed = FALSE;
-    src_fd = dst_fd = -1;
-    tmp = tmp0 = src = dst = tmpfile = NULL;
-    len = 0;
-    
-    /* open the file */
-
-    if ((src_fd = open(pe->file, O_RDONLY)) == -1) {
-        ui_error(op, "Unable to open '%s' for copying (%s)",
-                 pe->file, strerror(errno));
-        return NULL;
-    }
-
-    /* get the size of the file */
-
-    if (fstat(src_fd, &stat_buf) == -1) {
-        ui_error(op, "Unable to determine size of '%s' (%s)",
-                 pe->file, strerror(errno));
-        failed = TRUE; goto done;
-    }
-
-    /* mmap the file */
-
-    if ((src = mmap(0, stat_buf.st_size, PROT_READ,
-                    MAP_FILE|MAP_SHARED, src_fd, 0)) == MAP_FAILED) {
-        ui_error (op, "Unable to map source file '%s' for "
-                  "copying (%s)", pe->file, strerror(errno));
-        src = NULL;
-        failed = TRUE; goto done;
-    }
-
-    if (!src) {
-        ui_log(op, "%s is empty; skipping.", pe->file);
-        failed = TRUE; goto done;
-    }
-
-    /*
-     * allocate a string to hold the contents of the mmap'ed file,
-     * plus explicit NULL termination
-     */
-
-    tmp = nvalloc(stat_buf.st_size + 1);
-    memcpy(tmp, src, stat_buf.st_size);
-    tmp[stat_buf.st_size] = '\0';
-
-    /* setup to walk the tokens and replacements arrays */
-    
-    token = *tokens;
-    replacement = *replacements;
-
-    while (token != NULL && replacement != NULL) {
-        /*
-         * Replace any occurances of 'token' with 'replacement' in
-         * the source string and free the source
-         */
-        tmp0 = nv_strreplace(tmp, token, replacement);
-        nvfree(tmp);
-        tmp = tmp0;
-        token = *(++tokens);
-        replacement = *(++replacements);
-    }
-
-    /* create a temporary file to store the processed template file */
-    
-    tmpfile = nvstrcat(op->tmpdir, "/template-XXXXXX", NULL);
-    if ((dst_fd = mkstemp(tmpfile)) == -1) {
-        ui_error(op, "Unable to create temporary file (%s)",
-                 strerror(errno));
-        failed = TRUE; goto done;
-    }
-
-    /* set the size of the new file */
-
-    len = strlen(tmp);
-
-    if (lseek(dst_fd, len - 1, SEEK_SET) == -1) {
-        ui_error(op, "Unable to set file size for '%s' (%s)",
-                  tmpfile, strerror(errno));
-        failed = TRUE; goto done;
-    }
-    if (write(dst_fd, "", 1) != 1) {
-        ui_error(op, "Unable to write file size for '%s' (%s)",
-                 tmpfile, strerror(errno));
-        failed = TRUE; goto done;
-    }
-
-    /* mmap the new file */
-
-    if ((dst = mmap(0, len, PROT_READ | PROT_WRITE,
-                    MAP_FILE|MAP_SHARED, dst_fd, 0)) == MAP_FAILED) {
-        ui_error(op, "Unable to map destination file '%s' for "
-                 "copying (%s)", tmpfile, strerror(errno));
-        dst = NULL;
-        failed = TRUE; goto done;
-    }
-
-    /* write the processed data out to the temporary file */
-
-    memcpy(dst, tmp, len);
-
-done:
-
-    if (src) {
-        if (munmap(src, stat_buf.st_size) == -1) {
-            ui_error(op, "Unable to unmap source file '%s' after "
-                     "copying (%s)", pe->file,
-                     strerror(errno));
-        }
-    }
-    
-    if (dst) {
-        if (munmap(dst, len) == -1) {
-            ui_error (op, "Unable to unmap destination file '%s' "
-                      "after copying (%s)", tmpfile, strerror(errno));
-        }
-    }
-
-    if (src_fd != -1) close(src_fd);
-    if (dst_fd != -1) {
-        close(dst_fd);
-        /* in case an error occurred, delete the temporary file */
-        if (failed) unlink(tmpfile);
-    }
-
-    if (failed) {
-        nvfree(tmpfile); tmpfile = NULL;
-    }
-
-    nvfree(tmp);
-
-    return tmpfile;
-
-} /* process_template_files() */
-
-
-
 /*
  * process_libGL_la_files() - for any libGL.la files in the package,
  * copy them to a temporary file, replacing __GENERATED_BY__ and
@@ -1720,427 +1417,145 @@ done:
 
 void process_libGL_la_files(Options *op, Package *p)
 {
-    int i, n;
-    char *tmpfile;
-
-    char *tokens[3] = { "__LIBGL_PATH__", "__GENERATED_BY__", NULL };
-    char *replacements[3] = { NULL, NULL, NULL };
+    int i, n, src_fd, dst_fd, len;
+    struct stat stat_buf;
+    char *src, *dst, *tmp, *tmp0, *tmp1, *tmpfile;
 
     int package_num_entries = p->num_entries;
 
-    replacements[1] = nvstrcat(PROGRAM_NAME, ": ",
-                               NVIDIA_INSTALLER_VERSION, NULL);
-
     for (i = 0; i < package_num_entries; i++) {
         if ((p->entries[i].flags & FILE_TYPE_LIBGL_LA)) {
     
-            if (p->entries[i].flags & FILE_CLASS_COMPAT32) {
-                replacements[0] = nvstrcat(op->compat32_prefix,
-                                           "/", op->compat32_libdir, NULL);
-            } else {
-                replacements[0] = nvstrcat(op->opengl_prefix,
-                                           "/", op->opengl_libdir, NULL);
+            src_fd = dst_fd = -1;
+            tmp0 = tmp1 = src = dst = tmpfile = NULL;
+            len = 0;
+            
+            /* open the file */
+        
+            if ((src_fd = open(p->entries[i].file, O_RDONLY)) == -1) {
+                ui_error(op, "Unable to open '%s' for copying (%s)",
+                         p->entries[i].file, strerror(errno));
+                goto done;
             }
 
+            /* get the size of the file */
+
+            if (fstat(src_fd, &stat_buf) == -1) {
+                ui_error(op, "Unable to determine size of '%s' (%s)",
+                         p->entries[i].file, strerror(errno));
+                goto done;
+            }
+
+            /* mmap the file */
+
+            if ((src = mmap(0, stat_buf.st_size, PROT_READ,
+                            MAP_FILE|MAP_SHARED, src_fd, 0)) == (void *) -1) {
+                ui_error (op, "Unable to map source file '%s' for "
+                          "copying (%s)", p->entries[i].file, strerror(errno));
+                src = NULL;
+                goto done;
+            }
+
+            if (!src) {
+                ui_log(op, "%s is empty; skipping.", p->entries[i].file);
+                goto done;
+            }
+
+            /* replace __LIBGL_PATH__ */
+
+            tmp = nvstrcat(op->opengl_prefix, "/", p->entries[i].path, NULL);
+            tmp0 = nv_strreplace(src, "__LIBGL_PATH__", tmp);
+            nvfree(tmp);
+
+            /* replace __GENERATED_BY__ */
+
+            tmp = nvstrcat(PROGRAM_NAME, ": ", NVIDIA_INSTALLER_VERSION, NULL);
+            tmp1 = nv_strreplace(tmp0, "__GENERATED_BY__", tmp);
+            nvfree(tmp);
+
+            /* create a temporary file to store the processed libGL.la file */
+            
+            tmpfile = nvstrcat(op->tmpdir, "/libGL.la-XXXXXX", NULL);
+            if ((dst_fd = mkstemp(tmpfile)) == -1) {
+                ui_error(op, "Unable to create temporary file (%s)",
+                         strerror(errno));
+                goto done;
+            }
+
+            /* set the size of the new file */
+
+            len = strlen(tmp1);
+     
+            if (lseek(dst_fd, len - 1, SEEK_SET) == -1) {
+                ui_error(op, "Unable to set file size for '%s' (%s)",
+                          tmpfile, strerror(errno));
+                goto done;
+            }
+            if (write(dst_fd, "", 1) != 1) {
+                ui_error(op, "Unable to write file size for '%s' (%s)",
+                         tmpfile, strerror(errno));
+                goto done;
+            }
+
+            /* mmap the new file */
+
+            if ((dst = mmap(0, len, PROT_READ | PROT_WRITE,
+                            MAP_FILE|MAP_SHARED, dst_fd, 0)) == (void *) -1) {
+                ui_error(op, "Unable to map destination file '%s' for "
+                         "copying (%s)", tmpfile, strerror(errno));
+                dst = NULL;
+                goto done;
+            }
+
+            /* write the data out to the new file */
+
+            memcpy(dst, tmp1, len);
+
             /* invalidate the template file */
 
             p->entries[i].flags &= ~FILE_TYPE_MASK;
             p->entries[i].dst = NULL;
 
-            tmpfile = process_template_file(op, &p->entries[i], tokens,
-                                            replacements);
+            /* add this new file to the package */
+            
+            n = p->num_entries;
+            
+            p->entries =
+                (PackageEntry *) nvrealloc(p->entries,
+                                           (n + 1) * sizeof(PackageEntry));
+            p->entries[n].file = tmpfile;
+            p->entries[n].path = p->entries[i].path;
+            p->entries[n].target = NULL;
+            p->entries[n].flags = ((p->entries[i].flags & FILE_CLASS_MASK) |
+                                   FILE_TYPE_LIBGL_LA); 
+            p->entries[n].mode = p->entries[i].mode;
+            
+            p->entries[n].name = nvstrdup(p->entries[i].name);
+            
+            p->num_entries++;
 
-            if (tmpfile != NULL) {
-                /* add this new file to the package */
-                
-                n = p->num_entries;
-                
-                p->entries =
-                    (PackageEntry *) nvrealloc(p->entries,
-                                               (n + 1) * sizeof(PackageEntry));
-                p->entries[n].file = tmpfile;
-                p->entries[n].path = p->entries[i].path;
-                p->entries[n].target = NULL;
-                p->entries[n].flags = ((p->entries[i].flags & FILE_CLASS_MASK)
-                                        | FILE_TYPE_LIBGL_LA); 
-                p->entries[n].mode = p->entries[i].mode;
-                
-                p->entries[n].name = nvstrdup(p->entries[i].name);
-                
-                p->num_entries++;
+        done:
+
+            if (src) {
+                if (munmap(src, stat_buf.st_size) == -1) {
+                    ui_error(op, "Unable to unmap source file '%s' after "
+                             "copying (%s)", p->entries[i].file,
+                             strerror(errno));
+                }
+            }
+            
+            if (dst) {
+                if (munmap(dst, len) == -1) {
+                    ui_error (op, "Unable to unmap destination file '%s' "
+                              "after copying (%s)", tmpfile, strerror(errno));
+                }
             }
 
-            nvfree(replacements[0]);
+            if (src_fd != -1) close(src_fd);
+            if (dst_fd != -1) close(dst_fd);
+            
+            if (tmp0) nvfree(tmp0);
+            if (tmp1) nvfree(tmp1);
         }
     }
-
-    nvfree(replacements[1]);
-
 } /* process_libGL_la_files() */
-
-
-
-/*
- * process_dot_desktop_files() - for any .desktop files in the
- * package, copy them to a temporary file, replacing __UTILS_PATH__
- * and __PIXMAP_PATH__ as appropriate.  Then, add the new file to
- * the package list.
- */
-
-void process_dot_desktop_files(Options *op, Package *p)
-{
-    int i, n;
-    char *tmpfile;
-
-    char *tokens[3] = { "__UTILS_PATH__", "__PIXMAP_PATH__", NULL };
-    char *replacements[3] = { NULL, NULL, NULL };
-
-    int package_num_entries = p->num_entries;
-
-    replacements[0] = nvstrcat(op->utility_prefix,
-                               "/", op->utility_bindir, NULL);
-
-    remove_trailing_slashes(replacements[0]);
-    collapse_multiple_slashes(replacements[0]);
-
-    for (i = 0; i < package_num_entries; i++) {
-        if ((p->entries[i].flags & FILE_TYPE_DOT_DESKTOP)) {
-    
-            /* invalidate the template file */
-
-            p->entries[i].flags &= ~FILE_TYPE_MASK;
-            p->entries[i].dst = NULL;
-
-            nvfree(replacements[1]);
-
-            replacements[1] = nvstrcat(op->documentation_prefix,
-                                       "/", op->documentation_docdir,
-                                       "/", p->entries[i].path,
-                                       NULL);
-
-            remove_trailing_slashes(replacements[1]);
-            collapse_multiple_slashes(replacements[1]);
-
-            tmpfile = process_template_file(op, &p->entries[i], tokens,
-                                            replacements);
-            if (tmpfile != NULL) {
-                /* add this new file to the package */
-                
-                n = p->num_entries;
-                
-                p->entries =
-                    (PackageEntry *) nvrealloc(p->entries,
-                                               (n + 1) * sizeof(PackageEntry));
-                p->entries[n].file = tmpfile;
-                p->entries[n].path = p->entries[i].path;
-                p->entries[n].target = NULL;
-                p->entries[n].flags = ((p->entries[i].flags & FILE_CLASS_MASK)
-                                        | FILE_TYPE_DOT_DESKTOP); 
-                p->entries[n].mode = p->entries[i].mode;
-                
-                p->entries[n].name = nvstrdup(p->entries[i].name);
-                
-                p->num_entries++;
-            }
-        }
-    }
-
-    nvfree(replacements[0]);
-    nvfree(replacements[1]);
-
-} /* process_dot_desktop_files() */
-
-
-/*
- * set_security_context() - set the security context of the file to 'shlib_t'
- * Returns TRUE on success or if SELinux is disabled, FALSE otherwise
- */
-int set_security_context(Options *op, const char *filename) 
-{
-    char *cmd = NULL;
-    int ret = FALSE;
-    
-    if (op->selinux_enabled == FALSE) {
-        return TRUE;
-    } 
-    
-    cmd = nvstrcat(op->utils[CHCON], " -t ", op->selinux_chcon_type, " ",
-                   filename, NULL);
-    
-    ret = run_command(op, cmd, NULL, FALSE, 0, TRUE);
-    
-    ret = ((ret == 0) ? TRUE : FALSE);
-    if (cmd) nvfree(cmd);
-    
-    return ret;
-} /* set_security_context() */
-
-
-/*
- * get_default_prefixes_and_paths() - assign the default prefixes and
- * paths depending on the architecture, distribution and the X.Org
- * version installed on the system.
- */
-
-void get_default_prefixes_and_paths(Options *op)
-{
-    char *default_libdir;
-    
-#if defined(NV_X86_64)
-    if ((op->distro == DEBIAN) ||
-        (op->distro == UBUNTU)) {
-        default_libdir = DEBIAN_DEFAULT_64BIT_LIBDIR;
-    } else {
-        default_libdir = DEFAULT_64BIT_LIBDIR;
-    }
-#else
-    default_libdir = DEFAULT_LIBDIR;
-#endif
-
-    if (!op->opengl_prefix)
-        op->opengl_prefix = DEFAULT_OPENGL_PREFIX;
-    if (!op->opengl_libdir)
-        op->opengl_libdir = default_libdir;
-    if (!op->opengl_incdir)
-        op->opengl_incdir = DEFAULT_INCDIR;
-
-    if (!op->x_prefix) {
-        if (op->modular_xorg) {
-            op->x_prefix = XORG7_DEFAULT_X_PREFIX;
-        } else {
-            op->x_prefix = DEFAULT_X_PREFIX;
-        }
-    }
-    if (!op->x_libdir)
-        op->x_libdir = default_libdir;
-    if (!op->x_moddir) {
-        if (op->modular_xorg) {
-            op->x_moddir = XORG7_DEFAULT_X_MODULEDIR ;
-        } else {
-            op->x_moddir = DEFAULT_X_MODULEDIR;
-        }
-    }
-
-#if defined(NV_X86_64)
-    if (op->distro == DEBIAN && !op->compat32_chroot)
-        op->compat32_chroot = DEBIAN_DEFAULT_COMPAT32_CHROOT;
-
-    if (!op->compat32_prefix)
-        op->compat32_prefix = DEFAULT_OPENGL_PREFIX;
-
-    if (!op->compat32_libdir) {
-        if ((op->distro == UBUNTU) ||
-            (op->distro == GENTOO)) {
-            op->compat32_libdir = UBUNTU_DEFAULT_COMPAT32_LIBDIR;
-        } else {
-            op->compat32_libdir = DEFAULT_LIBDIR;
-        }
-    }
-#endif
-
-    if (!op->utility_prefix)
-        op->utility_prefix = DEFAULT_UTILITY_PREFIX;
-    if (!op->utility_libdir)
-        op->utility_libdir = default_libdir;
-    if (!op->utility_bindir)
-        op->utility_bindir = DEFAULT_BINDIR;
-
-    if (!op->dot_desktopdir)
-        op->dot_desktopdir = DEFAULT_DOT_DESKTOPDIR;
-
-    if (!op->documentation_prefix)
-        op->documentation_prefix = DEFAULT_DOCUMENTATION_PREFIX;
-    if (!op->documentation_docdir)
-        op->documentation_docdir = DEFAULT_DOCDIR;
-    if (!op->documentation_mandir)
-        op->documentation_mandir = DEFAULT_MANDIR;
-
-} /* get_default_prefixes_and_paths() */
-
-
-/*
- * get_xdg_data_dir() - determine if the XDG_DATA_DIRS environment
- * variable is set; if set and not empty, return the first path
- * in the list, else return NULL.
- */
-
-static char *get_xdg_data_dir(void)
-{
-    /*
-     * If XDG_DATA_DIRS is set, then derive the installation path
-     * from the first entry; complies with:
-     *   http://www.freedesktop.org/Standards/basedir-spec
-     */
-    char *xdg_data_dir = getenv("XDG_DATA_DIRS");
-    if ((xdg_data_dir != NULL) && strlen(xdg_data_dir))
-        return nvstrdup(strtok(xdg_data_dir, ":"));
-    return NULL;
-}
-
-
-/*
- * get_x_library_path() - assign op->x_library_path if it is not
- * already set.
- */
-
-static int get_x_library_path(Options *op)
-{
-    char *cmd, *dir = NULL;
-    int ret;
-
-    /*
-     * if the path was already specified (i.e.: by a command
-     * line option), then we are done.
-     */
-
-    if (op->x_library_path != NULL)
-        return TRUE;
-
-    if (!op->utils[PKG_CONFIG]) {
-        if (op->modular_xorg) {
-            ui_warn(op, "You appear to be using a modular X.Org "
-                    "release, but nvidia-installer could not find the "
-                    "`pkg-config` utility required to determine the "
-                    "correct X library installation path.  Please "
-                    "install the `pkg-config` utility and the X.Org "
-                    "SDK/development package for your distribution.");
-        }
-    } else {
-        /* ask pkg-config */
-
-        cmd = nvstrcat(op->utils[PKG_CONFIG],
-                       " --variable=libdir xorg-server", NULL);
-
-        ret = run_command(op, cmd, &dir, FALSE, 0, TRUE);
-        nvfree(cmd);
-
-        if ((ret != 0) || (dir == NULL)) {
-            if (op->modular_xorg) {
-                ui_warn(op, "You appear to be using a modular X.Org "
-                        "release, but nvidia-installer was unable to "
-                        "determine the correct X library "
-                        "installation path with the `pkg-config` "
-                        "utility.  Please install the X.Org SDK/"
-                        "development package for your distribution.");
-            }
-        } else {
-            if (!directory_exists(op, dir) &&
-                op->modular_xorg) {
-                ui_warn(op, "You appear to be using a modular X.Org "
-                        "release, but the X library installation "
-                        "path reported by `pkg-config "
-                        "--variable=libdir xorg-server` does "
-                        "not exist.  Please check your X.Org installation.");
-            } else {
-                op->x_library_path = dir;
-                return TRUE;
-            }
-        }
-        
-        nvfree(dir);
-    }
-
-    /* build the X library path */
-
-    op->x_library_path = nvstrcat(op->x_prefix, "/", op->x_libdir, NULL);
-
-    remove_trailing_slashes(op->x_library_path);
-    collapse_multiple_slashes(op->x_library_path);
-
-    if (op->modular_xorg) {
-        ui_warn(op, "nvidia-installer was unable to determine the "
-                "correct X library installation path and will "
-                "install the NVIDIA X libraries to '%s'.",
-                op->x_library_path);
-    }
-
-    return TRUE;
-
-} /* get_x_library_path() */
-
-
-/*
- * get_x_module_path() - assign op->x_module_path if it is not
- * already set.
- */
-
-static int get_x_module_path(Options *op)
-{
-    char *cmd, *dir = NULL;
-    int ret;
-
-    /*
-     * if the path was already specified (ie: by a commandline
-     * option), then we are done
-     */
-
-    if (op->x_module_path) {
-        return TRUE;
-    }
-
-    if (!op->utils[PKG_CONFIG]) {
-        if (op->modular_xorg) {
-            ui_warn(op, "You appear to be using a modular X.Org "
-                    "release, but nvidia-installer could not find the "
-                    "`pkg-config` utility required to determine the "
-                    "correct X module installation path.  Please "
-                    "install the `pkg-config` utility and the X.Org "
-                    "SDK/development package for your distribution.");
-        }
-    } else {
-        /* ask pkg-config */
-
-        cmd = nvstrcat(op->utils[PKG_CONFIG],
-                       " --variable=moduledir xorg-server",
-                       NULL);
-
-        ret = run_command(op, cmd, &dir, FALSE, 0, TRUE);
-        nvfree(cmd);
-
-        if ((ret != 0) || (dir == NULL)) {
-            if (op->modular_xorg) {
-                ui_warn(op, "You appear to be using a modular X.Org "
-                        "release, but nvidia-installer was unable to "
-                        "determine the correct X module "
-                        "installation path with the `pkg-config` "
-                        "utility.  Please install the X.Org SDK/"
-                        "development package for your distribution.");
-            }
-        } else {
-            if (!directory_exists(op, dir) &&
-                op->modular_xorg) {
-                ui_warn(op, "You appear to be using a modular X.Org "
-                        "release, but the X module installation "
-                        "path reported by `pkg-config "
-                        "--variable=moduledir xorg-server` does "
-                        "not exist.  Please check your X.Org installation.");
-            } else {
-                op->x_module_path = dir;
-                return TRUE;
-            }
-        }
-        
-        nvfree(dir);
-    }
-
-    /* build the X module path */
-
-    op->x_module_path =
-        nvstrcat(op->x_library_path, "/", op->x_moddir, NULL);
-
-    remove_trailing_slashes(op->x_module_path);
-    collapse_multiple_slashes(op->x_module_path);
-
-    if (op->modular_xorg) {
-        ui_warn(op, "nvidia-installer was unable to determine the "
-                "correct X module installation path and will "
-                "install the NVIDIA X driver components to '%s'.  "
-                "If X fails to find the NVIDIA X driver module, "
-                "please correct any `pkg-config` problems warned "
-                "about earlier and reinstall the driver.",
-                op->x_module_path);
-    }
-    
-    return TRUE;
-
-} /* get_x_module_path() */
