@@ -28,13 +28,17 @@
 #include "nvidia-installer.h"
 
 int remove_directory(Options *op, const char *victim);
+int touch_directory(Options *op, const char *victim);
 int copy_file(Options *op, const char *srcfile,
               const char *dstfile, mode_t mode);
+char *write_temp_file(Options *op, const int len,
+                      const unsigned char *data, mode_t perm);
 void select_tls_class(Options *op, Package *p); /* XXX move? */
 int set_destinations(Options *op, Package *p); /* XXX move? */
 int get_license_acceptance(Options *op); /* XXX move? */
 int get_prefixes(Options *op); /* XXX move? */
 int add_kernel_module_to_package(Options *op, Package *p);
+void remove_non_kernel_module_files_from_package(Options *op, Package *p);
 void remove_trailing_slashes(char *s);
 int mode_string_to_mode(Options *op, char *s, mode_t *mode);
 char *mode_to_permission_string(mode_t mode);
@@ -47,9 +51,11 @@ int install_file(Options *op, const char *srcfile,
 size_t get_file_size(Options *op, const char *filename);
 size_t fget_file_size(Options *op, const int fd);
 char *get_tmpdir(Options *op);
+char *make_tmpdir(Options *op);
 int nvrename(Options *op, const char *src, const char *dst);
 int check_for_existing_rpms(Options *op);
 int copy_directory_contents(Options *op, const char *src, const char *dst);
 int pack_precompiled_kernel_interface(Options *op, Package *p);
+void process_libGL_la_files(Options *op, Package *p);
 
 #endif /* __NVIDIA_INSTALLER_FILES_H__ */
