@@ -54,7 +54,8 @@
 
 
 static Package *parse_manifest(Options *op);
-static int install_kernel_module(Options *op,  Package *p);
+
+
 
 
 /*
@@ -78,7 +79,6 @@ int install_from_cwd(Options *op)
     Package *p;
     CommandList *c;
     const char *msg;
-    int ret;
 
     static const char edit_your_xf86config[] =
         "Please update your XF86Config or xorg.conf file as "
@@ -99,21 +99,14 @@ int install_from_cwd(Options *op)
     ui_set_title(op, "%s (%d.%d-%d)", p->description,
                  p->major, p->minor, p->patch);
 
-    /* 
-     * warn the user if "legacy" GPUs are installed in this system
-     * and if no supported GPU is found, at all.
-     */
-
-    check_for_nvidia_graphics_devices(op, p);
-
-    /* check that we are not running any X server */
-
-    if (!check_for_running_x(op)) goto failed;
-
     /* make sure the kernel module is unloaded */
     
     if (!check_for_unloaded_kernel_module(op, p)) goto failed;
     
+    /* check that we are not running any X server */
+
+    if (!check_for_running_x(op)) goto failed;
+
     /* ask the user to accept the license */
     
     if (!get_license_acceptance(op)) return FALSE;
@@ -123,21 +116,86 @@ int install_from_cwd(Options *op)
      * they really want to overwrite the existing installation
      */
 
+    /* print warning message if a legacy gpu is detected in the system */
+    
+    check_for_legacy_gpu(op, p);
+
     if (!check_for_existing_driver(op, p)) return FALSE;
+    
+    /* determine where to install the kernel module */
+    
+    if (!determine_kernel_module_installation_path(op)) goto failed;
 
-    /* attempt to build a kernel module for the target kernel */
+    /* check '/proc/sys/kernel/modprobe' */
+
+    if (!check_proc_modprobe_path(op)) return FALSE;
+
+    /*
+     * do nvchooser-style logic to decide if we have a prebuilt kernel
+     * module for their kernel
+     *
+     * XXX One could make the argument that we should not actually do
+     * the building/linking now, but just add this to the list of
+     * operations and do it when we execute the operation list.  I
+     * think it's better to make sure we have a kernel module early on
+     * -- a common problem for users will be not having a prebuilt
+     * kernel interface for their kernel, and not having the kernel
+     * headers installed, so it's better to catch that earlier on.
+     */
+    
+    if (find_precompiled_kernel_interface(op, p)) {
+
+        /*
+         * we have a prebuild kernel interface, so now link the kernel
+         * interface with the binary portion of the kernel module.
+         *
+         * XXX if linking fails, maybe we should fall through and
+         * attempt to build the kernel module?  No, if linking fails,
+         * then there is something pretty seriously wrong... better to
+         * abort.
+         */
+        
+        if (!link_kernel_module(op, p)) goto failed;
 
-    if (!op->no_kernel_module) {
-        if (!install_kernel_module(op, p)) goto failed;
     } else {
-        ui_warn(op, "You specified the '--no-kernel-module' command line "
-                "option, nvidia-installer will not install a kernel "
-                "module as part of this driver installation, and it will "
-                "not remove existing NVIDIA kernel modules not part of "
-                "an earlier NVIDIA driver installation.  Please ensure "
-                "that an NVIDIA kernel module matching this driver version "
-                "is installed seperately.");
+        /*
+         * make sure the required development tools are present on
+         * this system before attempting to verify the compiler and
+         * trying to build a custom kernel interface.
+         */
+        if (!check_development_tools(op)) goto failed;
+
+        /*
+         * we do not have a prebuilt kernel interface; thus we'll need
+         * to compile the kernel interface, so determine where the
+         * kernel header files are
+         */
+        
+        if (!determine_kernel_source_path(op)) goto failed;
+        determine_kernel_output_path(op);
+    
+        /*
+         * make sure that the selected or default system compiler
+         * is compatible with the target kernel; the user may choose
+         * to override the check.
+         */
+        if (!check_cc_version(op, p)) goto failed;
+
+        /* and now, build the kernel interface */
+        
+        if (!build_kernel_module(op, p)) goto failed;
     }
+
+    /*
+     * if we got this far, we have a complete kernel module; test it
+     * to be sure it's OK
+     */
+    
+    if (!test_kernel_module(op, p)) goto failed;
+    
+    /* add the kernel module to the list of things to install */
+    
+    if (!add_kernel_module_to_package(op, p)) goto failed;
     
     /*
      * if we are only installing the kernel module, then remove
@@ -165,14 +223,13 @@ int install_from_cwd(Options *op)
         select_tls_class(op, p);
 
         /*
-         * if the package contains any libGL.la or .desktop files,
-         * process them (perform some search and replacing so
-         * that they reflect the correct installation path, etc)
-         * and add them to the package list (files to be installed).
+         * if the package contains any libGL.la files, process them
+         * (perform some search and replacing so that they reflect the
+         * correct installation path, etc) and add them to the
+         * packagelist to be installed.
          */
         
         process_libGL_la_files(op, p);
-        process_dot_desktop_files(op, p);
 
 #if defined(NV_X86_64)
         /*
@@ -211,7 +268,7 @@ int install_from_cwd(Options *op)
 
     /* call the ui to get approval for the list of commands */
     
-    if (!ui_approve_command_list(op, c, "%s", p->description)) return FALSE;
+    if (!ui_approve_command_list(op, c, p->description)) return FALSE;
     
     /* initialize the backup log file */
 
@@ -222,6 +279,10 @@ int install_from_cwd(Options *op)
     /* execute the command list */
 
     if (!do_install(op, p, c)) goto failed;
+
+    /* 
+     * XXX IMPLEMENT ME: generate an XF86Config file?
+     */
   
     /*
      * check that everything is installed properly (post-install
@@ -235,41 +296,19 @@ int install_from_cwd(Options *op)
     
     /* done */
 
+    if ((op->distro == SUSE) || (op->distro == UNITED_LINUX)) {
+        msg = suse_edit_your_xf86config;
+    } else {
+        msg = edit_your_xf86config;
+    }
+    
     if (op->kernel_module_only) {
         ui_message(op, "Installation of the kernel module for the %s "
                    "(version %s) is now complete.",
                    p->description, p->version_string);
     } else {
-        
-        /* ask the user if they would like to run nvidia-xconfig */
-        
-        ret = ui_yes_no(op, op->run_nvidia_xconfig,
-                        "Would you like to run the nvidia-xconfig utility "
-                        "to automatically update your X configuration file "
-                        "so that the NVIDIA X driver will be used when you "
-                        "restart X?  Any pre-existing X configuration "
-                        "file will be backed up.");
-        
-        if (ret) {
-            ret = run_nvidia_xconfig(op);
-        }
-        
-        if (ret) {
-            ui_message(op, "Your X configuration file has been successfully "
-                       "updated.  Installation of the %s (version: %s) is now "
-                       "complete.", p->description, p->version_string);
-        } else {
-            
-            if ((op->distro == SUSE) || (op->distro == UNITED_LINUX)) {
-                msg = suse_edit_your_xf86config;
-            } else {
-                msg = edit_your_xf86config;
-            }
-            
-            ui_message(op, "Installation of the %s (version: %s) is now "
-                       "complete.  %s", p->description,
-                       p->version_string, msg);
-        }
+        ui_message(op, "Installation of the %s (version: %s) is now "
+                   "complete.  %s", p->description, p->version_string, msg);
     }
     
     return TRUE;
@@ -294,97 +333,6 @@ int install_from_cwd(Options *op)
 
 
 
-/*
- * install_kernel_module() - attempt to build and install a kernel
- * module for the running kernel; we first check if a prebuilt kernel
- * interface file exists. If yes, we try to link it into the final
- * kernel module, else we try to build one from source.
- *
- * If we succeed in building a kernel module, we attempt to load it
- * into the host kernel and add it to the list of files to install if
- * the load attempt succeeds.
- */
-
-static int install_kernel_module(Options *op,  Package *p)
-{
-    /* determine where to install the kernel module */
-    
-    if (!determine_kernel_module_installation_path(op)) return FALSE;
-
-    /* check '/proc/sys/kernel/modprobe' */
-
-    if (!check_proc_modprobe_path(op)) return FALSE;
-
-    /*
-     * do nvchooser-style logic to decide if we have a prebuilt kernel
-     * module for their kernel
-     *
-     * XXX One could make the argument that we should not actually do
-     * the building/linking now, but just add this to the list of
-     * operations and do it when we execute the operation list.  I
-     * think it's better to make sure we have a kernel module early on
-     * -- a common problem for users will be not having a prebuilt
-     * kernel interface for their kernel, and not having the kernel
-     * headers installed, so it's better to catch that earlier on.
-     */
-    
-    if (find_precompiled_kernel_interface(op, p)) {
-
-        /*
-         * we have a prebuild kernel interface, so now link the kernel
-         * interface with the binary portion of the kernel module.
-         *
-         * XXX if linking fails, maybe we should fall through and
-         * attempt to build the kernel module?  No, if linking fails,
-         * then there is something pretty seriously wrong... better to
-         * abort.
-         */
-        
-        if (!link_kernel_module(op, p)) return FALSE;
-
-    } else {
-        /*
-         * make sure the required development tools are present on
-         * this system before attempting to verify the compiler and
-         * trying to build a custom kernel interface.
-         */
-        if (!check_development_tools(op, p)) return FALSE;
-
-        /*
-         * make sure that the selected or default system compiler
-         * is compatible with the target kernel; the user may choose
-         * to override the check.
-         */
-        if (!check_cc_version(op, p)) return FALSE;
-
-        /*
-         * we do not have a prebuilt kernel interface; thus we'll need
-         * to compile the kernel interface, so determine where the
-         * kernel source files are.
-         */
-        
-        if (!determine_kernel_source_path(op, p)) return FALSE;
-    
-        /* and now, build the kernel interface */
-        
-        if (!build_kernel_module(op, p)) return FALSE;
-    }
-
-    /*
-     * if we got this far, we have a complete kernel module; test it
-     * to be sure it's OK
-     */
-    
-    if (!test_kernel_module(op, p)) return FALSE;
-    
-    /* add the kernel module to the list of things to install */
-    
-    if (!add_kernel_module_to_package(op, p)) return FALSE;
-    
-    return TRUE;
-}
-
-
 /*
  * add_this_kernel() - build a precompiled kernel interface for the
  * running kernel, and repackage the .run file to include the new
@@ -401,7 +349,7 @@ int add_this_kernel(Options *op)
 
     /* find the kernel header files */
 
-    if (!determine_kernel_source_path(op, p)) goto failed;
+    if (!determine_kernel_source_path(op)) goto failed;
 
     /* build the precompiled kernel interface */
 
@@ -484,13 +432,13 @@ static Package *parse_manifest (Options *op)
     /* the first line is the description */
 
     line = 1;
-    p->description = get_next_line(manifest, &ptr, manifest, len);
+    p->description = get_next_line(manifest, &ptr);
     if (!p->description) goto invalid_manifest_file;
     
     /* the second line is the version */
     
     line++;
-    p->version_string = get_next_line(ptr, &ptr, manifest, len);
+    p->version_string = get_next_line(ptr, &ptr);
     if (!p->version_string) goto invalid_manifest_file;
     if (!nvid_version(p->version_string, &p->major, &p->minor, &p->patch))
         goto invalid_manifest_file;
@@ -498,13 +446,13 @@ static Package *parse_manifest (Options *op)
     /* new third line is the kernel interface filename */
 
     line++;
-    p->kernel_interface_filename = get_next_line(ptr, &ptr, manifest, len);
+    p->kernel_interface_filename = get_next_line(ptr, &ptr);
     if (!p->kernel_interface_filename) goto invalid_manifest_file;
 
     /* the fourth line is the kernel module name */
 
     line++;
-    p->kernel_module_name = get_next_line(ptr, &ptr, manifest, len);
+    p->kernel_module_name = get_next_line(ptr, &ptr);
     if (!p->kernel_module_name) goto invalid_manifest_file;
 
     /*
@@ -513,7 +461,7 @@ static Package *parse_manifest (Options *op)
      */
 
     line++;
-    tmpstr = get_next_line(ptr, &ptr, manifest, len);
+    tmpstr = get_next_line(ptr, &ptr);
     if (!tmpstr) goto invalid_manifest_file;
 
     p->bad_modules = NULL;
@@ -534,7 +482,7 @@ static Package *parse_manifest (Options *op)
      */
 
     line++;
-    tmpstr = get_next_line(ptr, &ptr, manifest, len);
+    tmpstr = get_next_line(ptr, &ptr);
     if (!tmpstr) goto invalid_manifest_file;
 
     p->bad_module_filenames = NULL;
@@ -551,7 +499,7 @@ static Package *parse_manifest (Options *op)
     /* the seventh line is the kernel module build directory */
 
     line++;
-    p->kernel_module_build_directory = get_next_line(ptr, &ptr, manifest, len);
+    p->kernel_module_build_directory = get_next_line(ptr, &ptr);
     if (!p->kernel_module_build_directory) goto invalid_manifest_file;
     remove_trailing_slashes(p->kernel_module_build_directory);
 
@@ -561,8 +509,7 @@ static Package *parse_manifest (Options *op)
      */
 
     line++;
-    p->precompiled_kernel_interface_directory =
-        get_next_line(ptr, &ptr, manifest, len);
+    p->precompiled_kernel_interface_directory = get_next_line(ptr, &ptr);
     if (!p->precompiled_kernel_interface_directory)
         goto invalid_manifest_file;
     remove_trailing_slashes(p->precompiled_kernel_interface_directory);
@@ -573,7 +520,7 @@ static Package *parse_manifest (Options *op)
     line++;
     
     do {
-        buf = get_next_line(ptr, &ptr, manifest, len);
+        buf = get_next_line(ptr, &ptr);
         if ((!buf) || (buf[0] == '\0')) {
             done = TRUE;
         } else {
@@ -625,36 +572,22 @@ static Package *parse_manifest (Options *op)
                 p->entries[n].flags |= FILE_TYPE_OPENGL_LIB;
             else if (strcmp(flag, "LIBGL_LA") == 0)
                 p->entries[n].flags |= FILE_TYPE_LIBGL_LA;
-            else if (strcmp(flag, "XLIB_STATIC_LIB") == 0)
-                p->entries[n].flags |= FILE_TYPE_XLIB_STATIC_LIB;
-            else if (strcmp(flag, "XLIB_SHARED_LIB") == 0)
-                p->entries[n].flags |= FILE_TYPE_XLIB_SHARED_LIB;
+            else if (strcmp(flag, "XFREE86_LIB") == 0)
+                p->entries[n].flags |= FILE_TYPE_XFREE86_LIB;
             else if (strcmp(flag, "TLS_LIB") == 0)
                 p->entries[n].flags |= FILE_TYPE_TLS_LIB;
-            else if (strcmp(flag, "UTILITY_LIB") == 0)
-                p->entries[n].flags |= FILE_TYPE_UTILITY_LIB;
             else if (strcmp(flag, "DOCUMENTATION") == 0)
                 p->entries[n].flags |= FILE_TYPE_DOCUMENTATION;
-            else if (strcmp(flag, "MANPAGE") == 0)
-                p->entries[n].flags |= FILE_TYPE_MANPAGE;
             else if (strcmp(flag, "OPENGL_SYMLINK") == 0)
                 p->entries[n].flags |= FILE_TYPE_OPENGL_SYMLINK;
-            else if (strcmp(flag, "XLIB_SYMLINK") == 0)
-                p->entries[n].flags |= FILE_TYPE_XLIB_SYMLINK;
+            else if (strcmp(flag, "XFREE86_SYMLINK") == 0)
+                p->entries[n].flags |= FILE_TYPE_XFREE86_SYMLINK;
             else if (strcmp(flag, "TLS_SYMLINK") == 0)
                 p->entries[n].flags |= FILE_TYPE_TLS_SYMLINK;
-            else if (strcmp(flag, "UTILITY_SYMLINK") == 0)
-                p->entries[n].flags |= FILE_TYPE_UTILITY_SYMLINK;
             else if (strcmp(flag, "INSTALLER_BINARY") == 0)
                 p->entries[n].flags |= FILE_TYPE_INSTALLER_BINARY;
             else if (strcmp(flag, "UTILITY_BINARY") == 0)
                 p->entries[n].flags |= FILE_TYPE_UTILITY_BINARY;
-            else if (strcmp(flag, "DOT_DESKTOP") == 0)
-                p->entries[n].flags |= FILE_TYPE_DOT_DESKTOP;
-            else if (strcmp(flag, "XMODULE_SHARED_LIB") == 0)
-                p->entries[n].flags |= FILE_TYPE_XMODULE_SHARED_LIB;
-            else if (strcmp(flag, "XMODULE_SYMLINK") == 0)
-                p->entries[n].flags |= FILE_TYPE_XMODULE_SYMLINK;
             else {
                 nvfree(flag);
                 goto invalid_manifest_file;
