@@ -36,7 +36,6 @@
 #include <sys/mman.h>
 #include <string.h>
 #include <limits.h>
-#include <fts.h>
 
 #include "nvidia-installer.h"
 #include "kernel.h"
@@ -46,17 +45,18 @@
 #include "precompiled.h"
 #include "snarf.h"
 #include "crc.h"
+#include "nvLegacy.h"
 
 /* local prototypes */
 
 static char *default_kernel_module_installation_path(Options *op);
 static char *default_kernel_source_path(Options *op);
 static int check_for_loaded_kernel_module(Options *op, const char *);
-static void check_for_warning_messages(Options *op);
 static int rmmod_kernel_module(Options *op, const char *);
 static PrecompiledInfo *download_updated_kernel_interface(Options*, Package*,
                                                           const char*);
-static int fbdev_check(Options *op, Package *p);
+static int rivafb_check(Options *op, Package *p);
+static void change_page_attr_check(Options  *op, Package *p);
 
 static PrecompiledInfo *scan_dir(Options *op, Package *p,
                                  const char *directory_name,
@@ -72,12 +72,12 @@ static char *guess_kernel_module_filename(Options *op);
  */
 
 static const char install_your_kernel_source[] = 
-"Please make sure you have installed the kernel source files for "
-"your kernel and that they are properly configured; on Red Hat "
-"Linux systems, for example, be sure you have the 'kernel-source' "
-"or 'kernel-devel' RPM installed.  If you know the correct kernel "
-"source files are installed, you may specify the kernel source "
-"path with the '--kernel-source-path' command line option.";
+"Please make sure you have installed the kernel source files "
+"for your kernel; on Red Hat Linux systems, for example, be "
+"sure you have the 'kernel-source' rpm installed.  If you know the "
+"correct kernel source files are installed, you may specify the "
+"kernel source path with the '--kernel-source-path' "
+"commandline option.";
 
  
 
@@ -155,11 +155,10 @@ int determine_kernel_module_installation_path(Options *op)
  * FALSE if no kernel source tree was found.
  */
 
-int determine_kernel_source_path(Options *op, Package *p)
+int determine_kernel_source_path(Options *op)
 {
-    char *CC, *cmd, *result;
-    char *source_file, *source_path;
-    int ret, count = 0;
+    char *result;
+    int count = 0;
     
     /* determine the kernel source path */
     
@@ -244,51 +243,61 @@ int determine_kernel_source_path(Options *op, Package *p)
     }
     free(result);
 
-    if (!determine_kernel_output_path(op)) return FALSE;
+#if 0
 
-    CC = getenv("CC");
-    if (!CC) CC = "cc";
+    /*
+     * XXX The following heurisitic is broken: distribution-provided
+     * 2.6 kernel sources may not contain compile.h, even though they
+     * are valid to compile kernel modules against.  One suggestion
+     * has been to check for autoconf.h instead.  Disabling this
+     * entire check for now...
+     */
+
+    /*
+     * try to check that the kernel headers have been configured; this
+     * is complicated by the fact that 2.4 and 2.6 kernels have
+     * different header files.  Here is the heuristic:
+     *
+     * if compile.h exists:
+     *   this is a 2.6 kernel
+     *   if $(KERNEL_SOURCES)/Makefile does not exist
+     *     the kernel sources have not been configured
+     *
+     * if compile.h does not exit:
+     *   this is a 2.4 kernel
+     *   if modversions.h does not exist
+     *     the kernel sources have not been configured
+     */
+
+    compile_h = nvstrcat(op->kernel_source_path,
+                         "/include/linux/compile.h", NULL);
     
-    cmd = nvstrcat("sh ", p->kernel_module_build_directory,
-                   "/conftest.sh ", CC, " ", CC, " ",
-                   op->kernel_source_path, " ",
-                   op->kernel_output_path, " ",
-                   "get_uname", NULL);
-    
-    ret = run_command(op, cmd, &result, FALSE, 0, TRUE);
-    nvfree(cmd);
-
-    if (ret != 0) {
-        ui_error(op, "Unable to determine the version of the kernel "
-                 "sources located in '%s'.  %s",
-                 op->kernel_source_path, install_your_kernel_source);
-        free(result);
-        return FALSE;
-    }
-
-    if (strncmp(result, "2.4", 3) == 0) {
-        source_file = nvstrcat(op->kernel_source_path,
-                               "/include/linux/version.h", NULL);
-        source_path = op->kernel_source_path;
+    if (access(compile_h, F_OK) == 0) {
+        /* compile.h exists: this is a 2.6 kernel */
+        result = nvstrcat(op->kernel_source_path, "/Makefile", NULL);
     } else {
-        source_file = nvstrcat(op->kernel_output_path,
-                               "/include/linux/version.h", NULL);
-        source_path = op->kernel_output_path;
+        /* compile.h does not exist: this is a 2.4 kernel */
+        result = nvstrcat(op->kernel_source_path,
+                          "/include/linux/modversions.h", NULL);
     }
-    free(result);
-    
-    if (access(source_file, F_OK) != 0) {
+
+    free(compile_h);
+
+    if (access(result, F_OK) != 0) {
         ui_error(op, "The kernel header file '%s' does not exist.  "
                  "The most likely reason for this is that the kernel "
                  "source files in '%s' have not been configured.",
-                 source_file, source_path);
+                 result, op->kernel_source_path);
+        free(result);
         return FALSE;
     }
+    
+    free(result);
+#endif
 
     /* OK, we seem to have a path to a configured kernel source tree */
     
     ui_log(op, "Kernel source path: '%s'\n", op->kernel_source_path);
-    ui_log(op, "Kernel output path: '%s'\n", op->kernel_output_path);
     
     return TRUE;
     
@@ -414,7 +423,7 @@ int link_kernel_module(Options *op, Package *p)
 
 int build_kernel_module(Options *op, Package *p)
 {
-    char *CC, *result, *cmd, *tmp;
+    char *result, *cmd, *tmp;
     int len, ret;
     
     /*
@@ -424,15 +433,13 @@ int build_kernel_module(Options *op, Package *p)
     
     touch_directory(op, p->kernel_module_build_directory);
     
-    CC = getenv("CC");
-    if (!CC) CC = "cc";
-    
+
     /*
      * Check if conftest.sh can determine the Makefile, there's
      * no hope for the make rules if this fails.
      */
     cmd = nvstrcat("sh ", p->kernel_module_build_directory,
-                   "/conftest.sh ", CC, " ", CC, " ",
+                   "/conftest.sh cc ",
                    op->kernel_source_path, " ",
                    op->kernel_output_path, " ",
                    "select_makefile just_msg", NULL);
@@ -441,12 +448,13 @@ int build_kernel_module(Options *op, Package *p)
     nvfree(cmd);
 
     if (ret != 0) {
-        ui_error(op, "%s", result); /* display conftest.sh's error message */
+        ui_error(op, result); /* display conftest.sh's error message */
         nvfree(result);
         return FALSE;
     }
 
-    if (!fbdev_check(op, p)) return FALSE;
+    if (!rivafb_check(op, p)) return FALSE;
+    change_page_attr_check(op, p);
 
     cmd = nvstrcat("cd ", p->kernel_module_build_directory,
                    "; make print-module-filename",
@@ -620,46 +628,6 @@ int build_kernel_interface(Options *op, Package *p)
 
 
 
-/*
- * check_for_warning_messages() - check if the kernel module detected
- * problems with the target system and registered warning messages
- * for us with the Linux /proc interface. If yes, show these messages
- * to the user.
- */
-
-void check_for_warning_messages(Options *op)
-{
-    char *paths[2] = { "/proc/driver/nvidia/warnings", NULL };
-    FTS *fts;
-    FTSENT *ent;
-    char *buf = NULL;
-
-    fts = fts_open(paths, FTS_LOGICAL, NULL);
-    if (!fts) return;
-
-    while ((ent = fts_read(fts)) != NULL) {
-        switch (ent->fts_info) {
-            case FTS_F:
-                if ((strlen(ent->fts_name) == 6) &&
-                    !strncmp("README", ent->fts_name, 6))
-                    break;
-                if (read_text_file(ent->fts_path, &buf)) {
-                    ui_warn(op, "%s", buf);
-                    nvfree(buf);
-                }
-                break;
-            default:
-                /* ignore this file entry */
-                break;
-        }
-    }
-
-    fts_close(fts);
-
-} /* check_for_warning_messages() */
-
-
-
 /*
  * test_kernel_module() - attempt to insmod the kernel module and then
  * rmmod it.  Return TRUE if the insmod succeeded, or FALSE otherwise.
@@ -702,16 +670,6 @@ int test_kernel_module(Options *op, Package *p)
         nvfree(cmd);
     }
 
-    /*
-     * Likewise, we need to preload the i2c-core.ko kernel module to
-     * satisfy another dependency not resolved by `insmod`.
-     */
-    if (strncmp(get_kernel_name(op), "2.4", 3) != 0) {
-        cmd = nvstrcat(op->utils[MODPROBE], " -q i2c-core", NULL);
-        run_command(op, cmd, NULL, FALSE, 0, TRUE);
-        nvfree(cmd);
-    }
-
     cmd = nvstrcat(op->utils[INSMOD], " ",
                    p->kernel_module_build_directory, "/",
                    p->kernel_module_filename, NULL);
@@ -721,18 +679,10 @@ int test_kernel_module(Options *op, Package *p)
     ret = run_command(op, cmd, &data, op->expert, 0, TRUE);
 
     if (ret != 0) {
-        ui_error(op, "Unable to load the kernel module '%s'.  This "
-                 "happens most frequently when this kernel module was "
-                 "built against the wrong or improperly configured "
-                 "kernel sources, with a version of gcc that differs "
-                 "from the one used to build the target kernel, or "
-                 "if a driver such as rivafb/nvidiafb is present and "
-                 "prevents the NVIDIA kernel module from obtaining "
-                 "ownership of the NVIDIA graphics device(s).\n\n"
-                 "Please see the log entries 'Kernel module load "
-                 "error' and 'Kernel messages' at the end of the file "
-                 "'%s' for more information.",
-                 p->kernel_module_filename, op->log_file_name);
+        ui_error(op, "Unable to load the kernel module '%s'.  This is "
+                 "most likely because the kernel module was built using "
+                 "the wrong kernel source files.  %s",
+                 p->kernel_module_filename, install_your_kernel_source);
 
         /*
          * if in expert mode, run_command() would have caused this to
@@ -743,16 +693,21 @@ int test_kernel_module(Options *op, Package *p)
         if (!op->expert) ui_log(op, "Kernel module load error: %s", data);
         ret = FALSE;
 
-    } else {
         nvfree(cmd);
+        nvfree(data);
 
         /*
-         * check if the kernel module detected problems with this
-         * system's kernel and display any warning messages it may
-         * have prepared for us.
+         * display/log the last five lines of the kernel ring buffer
+         * to provide further details on the load failure.
          */
 
-        check_for_warning_messages(op);
+        cmd = nvstrcat(op->utils[DMESG], " | ",
+                       op->utils[TAIL], " -n 15", NULL);
+
+        if (!run_command(op, cmd, &data, FALSE, 0, TRUE))
+            ui_log(op, "Kernel messages:\n%s", data);
+    } else {
+        free(cmd);
 
         /*
          * attempt to unload the kernel module, but don't abort if
@@ -764,22 +719,8 @@ int test_kernel_module(Options *op, Package *p)
         ret = TRUE;
     }
     
-    nvfree(cmd);
-    nvfree(data);
-    
-    /*
-     * display/log the last few lines of the kernel ring buffer
-     * to provide further details in case of a load failure or
-     * to capture NVRM warning messages, if any.
-     */
-    cmd = nvstrcat(op->utils[DMESG], " | ",
-                   op->utils[TAIL], " -n 25", NULL);
-
-    if (!run_command(op, cmd, &data, FALSE, 0, TRUE))
-        ui_log(op, "Kernel messages:\n%s", data);
-
-    nvfree(cmd);
-    nvfree(data);
+    if (cmd) free(cmd);
+    if (data) free(data);
     
     if (new_loglevel != 0) sysctl(name, 2, NULL, 0, &old_loglevel, len);
     
@@ -817,8 +758,8 @@ int load_kernel_module(Options *op, Package *p)
         ret = TRUE;
     }
 
-    nvfree(cmd);
-    nvfree(data);
+    if (cmd) free(cmd);
+    if (data) free(data);
     
     return ret;
 
@@ -1325,7 +1266,6 @@ download_updated_kernel_interface(Options *op, Package *p,
 {
     int fd = -1;
     int dst_fd = -1;
-    int length;
     char *url = NULL;
     char *tmpfile = NULL;
     char *dstfile = NULL;
@@ -1361,12 +1301,10 @@ download_updated_kernel_interface(Options *op, Package *p,
     /* get the length of the file */
 
     if (fstat(fd, &stat_buf) == -1) goto done;
-
-    length = stat_buf.st_size;
     
     /* map the file into memory for easier reading */
     
-    str = mmap(0, length, PROT_READ, MAP_FILE | MAP_SHARED, fd, 0);
+    str = mmap(0, stat_buf.st_size, PROT_READ, MAP_FILE | MAP_SHARED, fd, 0);
     if (str == (void *) -1) goto done;
     
     /*
@@ -1377,7 +1315,7 @@ download_updated_kernel_interface(Options *op, Package *p,
     ptr = str;
 
     while (TRUE) {
-        buf = get_next_line(ptr, &ptr, str, length);
+        buf = get_next_line(ptr, &ptr);
         if ((!buf) || (buf[0] == '\0')) goto done;
 
         s = strstr(buf, ":::");
@@ -1500,15 +1438,27 @@ int check_cc_version(Options *op, Package *p)
         return TRUE;
     }
 
+    /*
+     * Check if the libc development headers are installed; we need
+     * these to build the gcc version check utility.
+     */
+    if (access("/usr/include/stdio.h", F_OK) == -1) {
+        ui_error(op, "You do not appear to have libc header files "
+                 "installed on your system.  Please install your "
+                 "distribution's libc development package.");
+        return FALSE;
+    }
+
     CC = getenv("CC");
     if (!CC) CC = "cc";
     
-    ui_log(op, "Performing CC version check with CC=\"%s\".", CC);
+    ui_log(op, "Performing CC test with CC=\"%s\".", CC);
 
     cmd = nvstrcat("sh ", p->kernel_module_build_directory,
-                   "/conftest.sh ", CC, " ", CC, " ",
-                   "DUMMY_SOURCE DUMMY_OUTPUT ",
-                   "cc_version_check just_msg", NULL);
+                   "/conftest.sh ", CC, " ",
+                   op->kernel_source_path, " ",
+                   op->kernel_output_path, " ",
+                   "cc_sanity_check just_msg", NULL);
 
     ret = run_command(op, cmd, &result, FALSE, 0, TRUE);
 
@@ -1516,7 +1466,7 @@ int check_cc_version(Options *op, Package *p)
 
     if (ret == 0) return TRUE;
 
-    ret = ui_yes_no(op, TRUE, "The CC version check failed:\n\n%s\n\n"
+    ret = ui_yes_no(op, TRUE, "gcc-version-check failed:\n\n%s\n\n"
                     "If you know what you are doing and want to "
                     "ignore the gcc version check, select \"No\" to "
                     "continue installation.  Otherwise, select \"Yes\" to "
@@ -1533,24 +1483,103 @@ int check_cc_version(Options *op, Package *p)
 } /* check_cc_version() */
 
 
+
 /*
- * fbdev_check() - run the rivafb_sanity_check and the nvidiafb_sanity_check
- * conftests; if either test fails, print the error message from the test
- * and abort the driver installation.
+ * check_for_legacy_gpu() - run 'lspci -n' and check if any of the returned pci_id 
+ * corresponds to a legacy gpu. If so, print a warning message for each of them, 
+ * and returns TRUE.
+ * Does not print any warning message and returns FALSE if no legacy GPU has been
+ * detected.
  */
 
-static int fbdev_check(Options *op, Package *p)
+int check_for_legacy_gpu(Options *op, Package *p)
 {
-    char *CC, *cmd, *result;
+    char *cmd = NULL, *data, *tok, *file;
     int ret;
+    unsigned int pci_id;
+    char hexdigits[] = "0123456789abcdef";
+    int hex[UCHAR_MAX];
+    int i;
+    int found=FALSE;
+  
+    // lspci not being in the path should not prevent the installation  
+    file=find_system_util("lspci");
+    if (file==NULL) 
+        return FALSE;
     
-    CC = getenv("CC");
-    if (!CC) CC = "cc";
+    cmd = nvstrcat(file, " -n | ",
+                       op->utils[CUT], " -d' ' -f4", NULL);
+    ret = run_command(op, cmd, &data, FALSE, 0, TRUE);
+    free(cmd);
+    free(file);
+    
+    if (ret != 0)
+        return FALSE;
+    
+    /* Convert to lower case then we can do insensitive string comparison */
+    nvstrtolower(data);
+    
+    /* Initialize tables for string->hex conversion */
+    for (i = 0; i < UCHAR_MAX; i++) 
+        hex[i] = 0;
+    for (i = 0; hexdigits[i] != '\0'; i++)
+        hex[(int)hexdigits[i]] = i;
+    
+    tok = strtok(data, "\n");
+    while(tok) {
+        if(strlen(tok)<9)
+            break;
+        
+        /* Check vendor id */ 
+        if(strncmp(tok, "10de", 4)) {
+            tok = strtok(NULL, "\n");
+            continue;
+        }
+        
+        /* Construct pci_id */
+        pci_id = (hex[(int)tok[5]] << 12) + 
+                 (hex[(int)tok[6]] << 8 ) +
+                 (hex[(int)tok[7]] << 4 ) + 
+                 (hex[(int)tok[8]]);
+        
+        for(i=0;i< sizeof(LegacyList) / sizeof(LEGACY_INFO); i++)
+        {
+            if(pci_id==LegacyList[i].uiDevId)
+            {
+                    ui_warn(op, "The NVIDIA %s GPU installed in this system is "
+                                "supported through the NVIDIA Legacy drivers. Please "
+                                "visit http://www.nvidia.com/object/unix.html for more "
+                                "information.  The %s NVIDIA driver will ignore "
+                                "this GPU. ",
+                                LegacyList[i].AdapterString, p->version_string);
+                    found = TRUE;
+            }
+        }
+        
+        tok = strtok(NULL, "\n");
+    }
+    
+    free(data);
+    return found;
+             
+} /* check_for_legacy_gpu() */
+
+
+/*
+ * rivafb_check() - run the rivafb_sanity_check conftest; if the test
+ * fails, print the error message from the test and abort driver
+ * installation.
+ */
+
+static int rivafb_check(Options *op, Package *p)
+{
+    char *cmd, *result;
+    int ret;
     
     ui_log(op, "Performing rivafb check.");
     
     cmd = nvstrcat("sh ", p->kernel_module_build_directory,
-                   "/conftest.sh ", CC, " ", CC, " ",
+                   "/conftest.sh cc ",
                    op->kernel_source_path, " ",
                    op->kernel_output_path, " ",
                    "rivafb_sanity_check just_msg", NULL);
@@ -1559,36 +1588,45 @@ static int fbdev_check(Options *op, Package *p)
     
     nvfree(cmd);
     
-    if (ret != 0) {
-        ui_error(op, "%s", result);
-        nvfree(result);
-
-        return FALSE;
-    }
-
-    ui_log(op, "Performing nvidiafb check.");
+    if (ret == 0) return TRUE;
     
+    ui_error(op, result);
+    
+    nvfree(result);
+    
+    return FALSE;
+    
+} /* rivafb_check() */
+
+
+/*
+ * change_page_attr_check() - run the change_page_attr_sanity_check
+ * conftest; if the test fails, print a warning messages, but continue
+ * the installation.
+ */
+
+static void change_page_attr_check(Options  *op, Package *p)
+{
+#if defined(NV_X86_64)
+    char *cmd, *result;
+    int ret;
+
+    ui_log(op, "Performing change_page_attr() check.");
+
     cmd = nvstrcat("sh ", p->kernel_module_build_directory,
-                   "/conftest.sh ", CC, " ", CC, " ",
+                   "/conftest.sh cc ",
                    op->kernel_source_path, " ",
                    op->kernel_output_path, " ",
-                   "nvidiafb_sanity_check just_msg", NULL);
+                   "change_page_attr_sanity_check just_msg", NULL);
     
     ret = run_command(op, cmd, &result, FALSE, 0, TRUE);
-    
     nvfree(cmd);
 
-    if (ret != 0) {
-        ui_error(op, "%s", result);
-        nvfree(result);
+    if (result && *result) ui_warn(op, result);
+    nvfree(result);
 
-        return FALSE;
-    }
-
-    return TRUE;
-    
-    
-} /* fbdev_check() */
+#endif /* NV_X86_64 */
+}
 
 
 
