@@ -28,7 +28,7 @@
 #include "nvidia-installer.h"
 
 int determine_kernel_module_installation_path (Options*);
-int determine_kernel_source_path              (Options*, Package*);
+int determine_kernel_source_path              (Options*);
 int determine_kernel_output_path              (Options*);
 int link_kernel_module                        (Options*, Package*);
 int check_cc_version                          (Options*, Package*);
@@ -40,5 +40,6 @@ int check_kernel_module_version               (Options*, Package*);
 int check_for_unloaded_kernel_module          (Options*, Package*);
 int find_precompiled_kernel_interface         (Options*, Package*);
 char *get_kernel_name                         (Options*);
+int check_for_legacy_gpu                      (Options*, Package*);
 
 #endif /* __NVIDIA_INSTALLER_KERNEL_H__ */
