@@ -31,7 +31,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <errno.h>
-#include <signal.h>
 #include <sys/types.h>
 #include <sys/utsname.h>
 #include <sys/stat.h>
@@ -40,7 +39,6 @@
 #include <sys/mman.h>
 #include <dirent.h>
 #include <libgen.h>
-#include <pci/pci.h>
 
 #include "nvidia-installer.h"
 #include "user-interface.h"
@@ -48,7 +46,6 @@
 #include "files.h"
 #include "misc.h"
 #include "crc.h"
-#include "nvLegacy.h"
 
 static int check_symlink(Options*, const char*, const char*, const char*);
 static int check_file(Options*, const char*, const mode_t, const uint32);
@@ -385,13 +382,9 @@ char *fget_next_line(FILE *fp, int *eof)
         if (buflen == len) { /* buffer isn't big enough -- grow it */
             buflen += NV_LINE_LEN;
             tmpbuf = (char *) nvalloc (buflen);
-            if (!tmpbuf) {
-                if (buf) nvfree(buf);
-                return NULL;
-            }
             if (buf) {
                 memcpy (tmpbuf, buf, len);
-                nvfree(buf);
+                free (buf);
             }
             buf = tmpbuf;
             c = buf + len;
@@ -417,15 +410,11 @@ char *fget_next_line(FILE *fp, int *eof)
 
 
 /*
- * get_next_line() - this function scans for the next newline,
- * carriage return, NUL terminator, or EOF in buf.  If non-NULL, the
- * passed-by-reference parameter 'end' is set to point to the next
- * printable character in the buffer, or NULL if EOF is encountered.
+ * get_next_line() - this function scans for the next newline or
+ * carriage return in buf.  If non-NULL, the passed-by-reference
+ * parameter e is set to point to the next printable character in the
+ * buffer, or NULL if EOF is encountered.
  *
- * If the parameter 'start' is non-NULL, then that is interpretted as
- * the start of the buffer string, and we check that we never walk
- * 'length' bytes past 'start'.
- * 
  * On success, a newly allocated buffer is allocated containing the
  * next line of text (with a NULL terminator in place of the
  * newline/carriage return).
@@ -433,46 +422,27 @@ char *fget_next_line(FILE *fp, int *eof)
  * On error, NULL is returned.
  */
 
-char *get_next_line(char *buf, char **end, char *start, int length)
+char *get_next_line(char *buf, char **e)
 {
     char *c, *retbuf;
     int len;
 
-    if (start && (length < 1)) return NULL;
+    if (e) *e = NULL;
+    
+    if ((!buf) || (*buf == '\0') || (*buf == EOF)) return NULL;
 
-#define __AT_END(_start, _current, _length) \
-    ((_start) && (((_current) - (_start)) >= (_length)))
-    
-    if (end) *end = NULL;
-    
-    if ((!buf) ||
-        __AT_END(start, buf, length) ||
-        (*buf == '\0') ||
-        (*buf == EOF)) return NULL;
-    
     c = buf;
-    
-    while ((!__AT_END(start, c, length)) &&
-           (*c != '\0') &&
-           (*c != EOF) &&
-           (*c != '\n') &&
-           (*c != '\r')) c++;
+    while ((*c != '\0') && (*c != EOF) && (*c != '\n') && (*c != '\r')) c++;
 
     len = c - buf;
     retbuf = nvalloc(len + 1);
     strncpy(retbuf, buf, len);
     retbuf[len] = '\0';
     
-    if (end) {
-        while ((!__AT_END(start, c, length)) &&
-               (*c != '\0') &&
-               (*c != EOF) &&
-               (!isprint(*c))) c++;
-        
-        if (__AT_END(start, c, length) ||
-            (*c == '\0') ||
-            (*c == EOF)) *end = NULL;
-        else *end = c;
+    if (e) {
+        while ((*c != '\0') && (*c != EOF) && (!isprint(*c))) c++;
+        if ((*c == '\0') || (*c == EOF)) *e = NULL;
+        else *e = c;
     }
     
     return retbuf;
@@ -510,7 +480,6 @@ int run_command(Options *op, const char *cmd, char **data, int output,
     int n, len, buflen, ret;
     char *cmd2, *buf, *tmpbuf;
     FILE *stream = NULL;
-    struct sigaction act, old_act;
     float percent;
     
     if (data) *data = NULL;
@@ -530,21 +499,6 @@ int run_command(Options *op, const char *cmd, char **data, int output,
         cmd2 = nvstrdup(cmd);
     }
     
-    /*
-     * XXX: temporarily ignore SIGWINCH; our child process inherits
-     * this disposition and will likewise ignore it (by default).
-     * This fixes cases where child processes abort after receiving
-     * SIGWINCH when its caught in the parent process.
-     */
-    if (op->sigwinch_workaround) {
-        act.sa_handler = SIG_IGN;
-        sigemptyset(&act.sa_mask);
-        act.sa_flags = 0;
-
-        if (sigaction(SIGWINCH, &act, &old_act) < 0)
-            old_act.sa_handler = NULL;
-    }
-
     /*
      * Open a process by creating a pipe, forking, and invoking the
      * command.
@@ -582,7 +536,7 @@ int run_command(Options *op, const char *cmd, char **data, int output,
         
         if (fgets(buf + len, buflen - len, stream) == NULL) break;
         
-        if (output) ui_command_output(op, "%s", buf + len);
+        if (output) ui_command_output(op, buf + len);
         
         len += strlen(buf + len);
 
@@ -590,14 +544,6 @@ int run_command(Options *op, const char *cmd, char **data, int output,
             n++;
             if (n > status) n = status;
             percent = (float) n / (float) status;
-
-            /*
-             * XXX: manually call the SIGWINCH handler, if set, to
-             * handle window resizes while we ignore the signal.
-             */
-            if (op->sigwinch_workaround)
-                if (old_act.sa_handler) old_act.sa_handler(SIGWINCH);
-
             ui_status_update(op, percent, NULL);
         }
     } /* while (1) */
@@ -606,13 +552,6 @@ int run_command(Options *op, const char *cmd, char **data, int output,
 
     ret = pclose(stream);
 
-    /*
-     * Restore the SIGWINCH signal disposition and handler, if any,
-     * to their original values.
-     */
-    if (op->sigwinch_workaround)
-        sigaction(SIGWINCH, &old_act, NULL);
-
     /* if the last character in the buffer is a newline, null it */
     
     if ((len > 0) && (buf[len-1] == '\n')) buf[len-1] = '\0';
@@ -626,54 +565,6 @@ int run_command(Options *op, const char *cmd, char **data, int output,
 
 
 
-/*
- * read_text_file() - open a text file, read its contents and return
- * them to the caller in a newly allocated buffer.  Returns TRUE on
- * success and FALSE on failure.
- */
-
-int read_text_file(const char *filename, char **buf)
-{
-    FILE *fp;
-    int index = 0, buflen = 0;
-    int eof = FALSE;
-    char *line, *tmpbuf;
-
-    *buf = NULL;
-
-    fp = fopen(filename, "r");
-    if (!fp)
-        return FALSE;
-
-    while (((line = fget_next_line(fp, &eof))
-                != NULL) && !eof) {
-        if ((index + strlen(line) + 1) > buflen) {
-            buflen += 2 * strlen(line);
-            tmpbuf = (char *)nvalloc(buflen);
-            if (!tmpbuf) {
-                if (*buf) nvfree(*buf);
-                fclose(fp);
-                return FALSE;
-            }
-            if (*buf) {
-                memcpy(tmpbuf, *buf, index);
-                nvfree(*buf);
-            }
-            *buf = tmpbuf;
-        }
-
-        index += sprintf(*buf + index, "%s\n", line);
-        nvfree(line);
-    }
-
-    fclose(fp);
-
-    return TRUE;
-
-} /* read_text_file() */
-
-
-
 /*
  * find_system_utils() - search the $PATH (as well as some common
  * additional directories) for the utilities that the installer will
@@ -683,7 +574,7 @@ int read_text_file(const char *filename, char **buf)
  * XXX requiring ld may cause problems
  */
 
-#define EXTRA_PATH "/bin:/usr/bin:/sbin:/usr/sbin:/usr/X11R6/bin:/usr/bin/X11"
+#define EXTRA_PATH "/bin:/usr/bin:/sbin:/usr/sbin"
 
 int find_system_utils(Options *op)
 {
@@ -699,16 +590,7 @@ int find_system_utils(Options *op)
         { "cut",      "coreutils" }
     };
     
-    /* keep in sync with the SystemOptionalUtils enum type */
-    const struct { const char *util, *package; } optional_utils[] = {
-        { "chcon",          "selinux" },
-        { "selinuxenabled", "selinux" },
-        { "getenforce",     "selinux" },
-        { "pkg-config",     "pkg-config" },
-        { "X",              "xserver" }
-    };
-    
-    int i, j;
+    int i;
 
     ui_expert(op, "Searching for system utilities:");
 
@@ -730,17 +612,6 @@ int find_system_utils(Options *op)
                   needed_utils[i].util, op->utils[i]);
     }
     
-    for (j = 0, i = MAX_SYSTEM_UTILS; i < MAX_SYSTEM_OPTIONAL_UTILS; i++, j++) {
-        
-        op->utils[i] = find_system_util(optional_utils[j].util);
-        if (op->utils[i]) {     
-            ui_expert(op, "found `%s` : `%s`",
-                  optional_utils[j].util, op->utils[i]);
-        } else {
-            op->utils[i] = NULL;
-        }
-    }
-    
     return TRUE;
 
 } /* find_system_utils() */
@@ -779,7 +650,7 @@ static Util __module_utils_linux24[] = {
 
 int find_module_utils(Options *op)
 {
-    int i, j;
+    int i, j = 0;
     Util *needed_utils = __module_utils;
 
     if (strncmp(get_kernel_name(op), "2.4", 3) == 0)
@@ -789,7 +660,7 @@ int find_module_utils(Options *op)
 
     /* search the PATH for each utility */
 
-    for (j=0, i = MAX_SYSTEM_OPTIONAL_UTILS; i < MAX_UTILS; i++, j++) {
+    for (i = MAX_SYSTEM_UTILS; i < MAX_UTILS; i++, j++) {
         op->utils[i] = find_system_util(needed_utils[j].util);
         if (!op->utils[i]) {
             ui_error(op, "Unable to find the module utility `%s`; please "
@@ -887,7 +758,7 @@ int check_proc_modprobe_path(Options *op)
  * to build custom kernel interfaces are available.
  */
 
-int check_development_tools(Options *op, Package *p)
+int check_development_tools(Options *op)
 {
 #define MAX_TOOLS 2
     const struct { char *tool, *package; } needed_tools[] = {
@@ -895,23 +766,12 @@ int check_development_tools(Options *op, Package *p)
         { "make", "make" }
     };
 
-    int i, ret;
-    char *tool, *cmd, *CC, *result;
-
-    CC = getenv("CC");
+    int i;
+    char *tool;
 
     ui_expert(op, "Checking development tools:");
 
-    /*
-     * Check if the required toolchain components are installed on
-     * the system.  Note that we skip the check for `cc` if the
-     * user specified the CC environment variable; we do this because
-     * `cc` may not be present in the path, nor the compiler named
-     * in $CC, but the installation may still succeed. $CC is sanity
-     * checked below.
-     */
-
-    for (i = (CC != NULL) ? 1 : 0; i < MAX_TOOLS; i++) {
+    for (i = 0; i < MAX_TOOLS; i++) {
         tool = find_system_util(needed_tools[i].tool);
         if (!tool) {
             ui_error(op, "Unable to find the development tool `%s` in "
@@ -927,37 +787,7 @@ int check_development_tools(Options *op, Package *p)
         ui_expert(op, "found `%s` : `%s`", needed_tools[i].tool, tool);
     }
 
-    /*
-     * Check if the libc development headers are installed; we need
-     * these to build the CC version check utility.
-     */
-    if (access("/usr/include/stdio.h", F_OK) == -1) {
-        ui_error(op, "You do not appear to have libc header files "
-                 "installed on your system.  Please install your "
-                 "distribution's libc development package.");
-        return FALSE;
-    }
-
-    if (!CC) CC = "cc";
-
-    ui_log(op, "Performing CC sanity check with CC=\"%s\".", CC);
-
-    cmd = nvstrcat("sh ", p->kernel_module_build_directory,
-                   "/conftest.sh ", CC, " ", CC, " ",
-                   "DUMMY_SOURCE DUMMY_OUTPUT ",
-                   "cc_sanity_check just_msg", NULL);
-
-    ret = run_command(op, cmd, &result, FALSE, 0, TRUE);
-
-    nvfree(cmd);
-
-    if (ret == 0) return TRUE;
-
-    ui_error(op, "The CC sanity check failed:\n\n%s\n", result);
-
-    nvfree(result);
-
-    return FALSE;
+    return TRUE;
 
 } /* check_development_tools() */
 
@@ -970,7 +800,7 @@ int check_development_tools(Options *op, Package *p)
 
 char *find_system_util(const char *util)
 {
-    char *buf, *path, *file, *x, *y, c;
+    char *buf, *path, *file, *x, *y;
     
     /* build the search path */
     
@@ -983,19 +813,17 @@ char *find_system_util(const char *util)
 
     /* search the PATH for the utility */
 
-    for (x = y = path; ; x++) {
-        if (*x == ':' || *x == '\0') {
-            c = *x;
+    for (x = y = path; *x; x++) {
+        if (*x == ':') {
             *x = '\0';
             file = nvstrcat(y, "/", util, NULL);
-            *x = c;
+            *x = ':';
             if ((access(file, F_OK | X_OK)) == 0) {
                 nvfree(path);
                 return file;
             }
             nvfree(file);
             y = x + 1;
-            if (*x == '\0') break;
         }
     }
 
@@ -1070,8 +898,6 @@ int continue_after_error(Options *op, const char *fmt, ...)
                     "error during installation: '%s'.  Continue anyway? "
                     "(\"no\" will abort)?", msg);
 
-    nvfree(msg);
-
     return ret;
 
 } /* continue_after_error() */
@@ -1162,7 +988,7 @@ void should_install_opengl_headers(Options *op, Package *p)
 void should_install_compat32_files(Options *op, Package *p)
 {
 #if defined(NV_X86_64)
-    int i, have_compat32_files = FALSE, install_compat32_files;
+    int i, have_compat32_files = FALSE;
 
     /*
      * first, scan through the package to see if we have any
@@ -1179,30 +1005,8 @@ void should_install_compat32_files(Options *op, Package *p)
     if (!have_compat32_files)
         return;
 
-    /*
-     * Ask the user if the 32-bit compatibility libraries are
-     * to be installed. If yes, check if the chosen prefix
-     * exists. If not, notify the user and ask him/her if the
-     * files are to be installed anyway.
-     */
-    install_compat32_files = ui_yes_no(op, TRUE,
-                "Install NVIDIA's 32-bit compatibility OpenGL "
-                "libraries?");
-
-    if (install_compat32_files && (op->compat32_chroot != NULL) &&
-          access(op->compat32_chroot, F_OK) < 0) {
-        install_compat32_files = ui_yes_no(op, FALSE,
-            "The NVIDIA 32-bit compatibility OpenGL libraries are "
-            "to be installed relative to the top-level prefix (chroot) "
-            "'%s'; however, this directory does not exist.  Please "
-            "consult your distribution's documentation to confirm the "
-            "correct top-level installation prefix for 32-bit "
-            "compatiblity libraries.\n\nDo you wish to install the "
-            "32-bit NVIDIA OpenGL compatibility libraries anyway?",
-            op->compat32_chroot);
-    }
-    
-    if (!install_compat32_files) {
+    if (!ui_yes_no(op, TRUE, "Install NVIDIA's 32bit compatibility "
+                   "OpenGL libraries?")) {
         for (i = 0; i < p->num_entries; i++) {
             if (p->entries[i].flags & FILE_CLASS_COMPAT32) {
                 /* invalidate file */
@@ -1511,17 +1315,6 @@ static int tls_test_internal(Options *op, int which_tls,
         goto done;
     }
     
-    if (set_security_context(op, dso_tmpfile) == FALSE) {
-        /* We are on a system with SELinux and the chcon command failed.
-         * Assume that the system is recent enough to have the new TLS
-         */
-        ui_warn(op, "Unable to set the security context on file %s; "
-                    "assuming new tls.",
-                     dso_tmpfile);
-        ret = TRUE;
-        goto done;
-    }
-
     /* run the test */
 
     cmd = nvstrcat(tmpfile, " ", dso_tmpfile, NULL);
@@ -1633,34 +1426,6 @@ void collapse_multiple_slashes(char *s)
 }
 
 
-
-/*
- * is_symbolic_link_to() - check if the file with path 'path' is
- * a symbolic link pointing to 'dest'.  Returns TRUE if this is
- * the case; if the file is not a symbolic link if it doesn't point
- * to 'dest', is_symbolic_link_to() returns FALSE.
- */
-
-int is_symbolic_link_to(const char *path, const char *dest)
-{
-    struct stat stat_buf0, stat_buf1;
-
-    if ((lstat(path, &stat_buf0) != 0)
-            || !S_ISLNK(stat_buf0.st_mode))
-        return FALSE;
-
-    if ((stat(path, &stat_buf0) == 0) &&
-        (stat(dest, &stat_buf1) == 0) &&
-        (stat_buf0.st_dev == stat_buf1.st_dev) &&
-        (stat_buf0.st_ino == stat_buf1.st_ino))
-        return TRUE;
-
-    return FALSE;
-
-} /* is_symbolic_link_to() */
-
-
-
 /*
  * rtld_test_internal() - this routine writes the test binaries to a file
  * and performs the test; the caller (rtld_test()) selects which array data
@@ -1673,10 +1438,9 @@ static int rtld_test_internal(Options *op, Package *p,
                               const int test_array_size,
                               int compat_32_libs)
 {
-    int fd, i, found = TRUE, ret = TRUE;
+    int i, ret = TRUE;
     char *name = NULL, *cmd = NULL, *data = NULL;
     char *tmpfile, *s;
-    char *tmpfile1 = NULL;
     struct stat stat_buf0, stat_buf1;
 
     if ((test_array == NULL) || (test_array_size == 0)) {
@@ -1697,19 +1461,6 @@ static int rtld_test_internal(Options *op, Package *p,
         goto done;
     }
 
-    /* create another temporary file */
-
-    tmpfile1 = nvstrcat(op->tmpdir, "/nv-tmp-XXXXXX", NULL);
-    
-    fd = mkstemp(tmpfile1);
-    if (fd == -1) {
-        ui_warn(op, "Unable to create a temporary file for the runtime "
-                "configuration test program (%s); assuming successful "
-                "installation.", strerror(errno));
-        goto done;
-    }
-    close(fd);
-
     /* perform the test(s) */
 
     for (i = 0; i < p->num_entries; i++) {
@@ -1740,52 +1491,27 @@ static int rtld_test_internal(Options *op, Package *p,
         if (!s) goto next;
         *(s + strlen(".so.1")) = '\0';
 
-        cmd = nvstrcat(op->utils[LDD], " ", tmpfile, " > ", tmpfile1, NULL);
+        cmd = nvstrcat(op->utils[LDD], " ", tmpfile, " | ",
+                       op->utils[GREP], " ", name, " | ",
+                       op->utils[CUT], " -d \" \" -f 3", NULL);
 
-        if (run_command(op, cmd, NULL, FALSE, 0, TRUE)) {
+        if (run_command(op, cmd, &data, FALSE, 0, TRUE)) {
             ui_warn(op, "Unable to perform the runtime configuration "
-                    "check for library '%s' ('%s'); assuming successful "
-                    "installation.", name, p->entries[i].dst);
+                    "check (%s); assuming successful installation.",
+                    strerror(errno));
             goto done;
         }
 
-        cmd = nvstrcat(op->utils[GREP], " ", name, " ", tmpfile1,
-                             " | ", op->utils[CUT], " -d \" \" -f 3", NULL);
-
-        if (run_command(op, cmd, &data, FALSE, 0, TRUE) ||
-                (data == NULL)) {
-            ui_warn(op, "Unable to perform the runtime configuration "
-                    "check for library '%s' ('%s'); assuming successful "
-                    "installation.", name, p->entries[i].dst);
-            goto done;
-        }
-
-        if (!strcmp(data, "not") || !strlen(data)) {
-            /*
-             * If the library didn't show up in ldd's output or
-             * wasn't found, set 'found' to false and notify the
-             * user with a more meaningful message below.
-             */
-            free(data); data = NULL;
-            found = FALSE;
-        } else {
-            /*
-             * Double slashes in /etc/ld.so.conf make it all the
-             * way to ldd's output on some systems. Strip them
-             * here to make sure they don't cause a false failure.
-             */
-            collapse_multiple_slashes(data);
-        }
-
         nvfree(name); name = NULL;
         name = nvstrdup(p->entries[i].dst);
         if (!name) goto next;
 
+        collapse_multiple_slashes(data);
         s = strstr(name, ".so.1");
         if (!s) goto next;
         *(s + strlen(".so.1")) = '\0';
 
-        if (!found || (strcmp(data, name) != 0)) {
+        if ((strcmp(data, name) != 0)) {
             /*
              * XXX Handle the case where the same library is
              * referred to, once directly and once via a symbolic
@@ -1795,46 +1521,21 @@ static int rtld_test_internal(Options *op, Package *p,
 
             if ((stat(data, &stat_buf0) == 0) &&
                 (stat(name, &stat_buf1) == 0) &&
-                (stat_buf0.st_dev == stat_buf1.st_dev) &&
-                (stat_buf0.st_ino == stat_buf1.st_ino))
+                (memcmp(&stat_buf0, &stat_buf1, sizeof(struct stat)) == 0))
                 goto next;
 
-            if (!found && !compat_32_libs) {
-                ui_error(op, "The runtime configuration check failed for "
-                         "library '%s' (expected: '%s', found: (not found)).  "
-                         "The most likely reason for this is that the library "
-                         "was installed to the wrong location or that your "
-                         "system's dynamic loader configuration needs to be "
-                         "updated.  Please check the OpenGL library installation "
-                         "prefix and/or the dynamic loader configuration.",
-                         p->entries[i].name, name);
-                ret = FALSE;
-                goto done;
-#if defined(NV_X86_64)
-            } else if (!found) {
-                ui_warn(op, "The runtime configuration check failed for "
-                        "library '%s' (expected: '%s', found: (not found)).  "
-                        "The most likely reason for this is that the library "
-                        "was installed to the wrong location or that your "
-                        "system's dynamic loader configuration needs to be "
-                        "updated.  Please check the 32-bit OpenGL compatibility "
-                        "library installation prefix and/or the dynamic loader "
-                        "configuration.",
-                         p->entries[i].name, name);
-                goto next;
-#endif /* NV_X86_64 */
-            } else {
-                ui_error(op, "The runtime configuration check failed for the "
-                         "library '%s' (expected: '%s', found: '%s').  The "
-                         "most likely reason for this is that conflicting "
-                         "OpenGL libraries are installed in a location not "
-                         "inspected by `nvidia-installer`.  Please be sure you "
-                         "have uninstalled any third-party OpenGL and/or "
-                         "third-party graphics driver packages.",
-                         p->entries[i].name, name, data);
-                ret = FALSE;
-                goto done;
-            }
+            ui_error(op, "The runtime configuration check failed for "
+                     "library '%s' (expected: '%s', found: '%s').  "
+                     "The most likely reason for this is that conflicting "
+                     "OpenGL libraries are installed in a location "
+                     "not inspected by `nvidia-installer`.  Please be sure "
+                     "you have uninstalled any third-party OpenGL and "
+                     "third-party graphics driver packages.",
+                     p->entries[i].name, name,
+                     (data && strlen(data)) ? data : "(not found)");
+
+            ret = FALSE;
+            goto done;
         }
 
  next:
@@ -1848,10 +1549,6 @@ static int rtld_test_internal(Options *op, Package *p,
         unlink(tmpfile);
         nvfree(tmpfile);
     }
-    if (tmpfile1) {
-        unlink(tmpfile1);
-        nvfree(tmpfile1);
-    }
 
     nvfree(name);
     nvfree(cmd);
@@ -1873,35 +1570,8 @@ static int rtld_test_internal(Options *op, Package *p,
 
 Distribution get_distribution(Options *op)
 {
-    FILE *fp;
-    char *line = NULL, *ptr;
-    int eof = FALSE;
-
     if (access("/etc/SuSE-release", F_OK) == 0) return SUSE;
     if (access("/etc/UnitedLinux-release", F_OK) == 0) return UNITED_LINUX;
-    if (access("/etc/gentoo-release", F_OK) == 0) return GENTOO;
-
-    /*
-     * Attempt to determine if the host system is 'Ubuntu Linux'
-     * based by checking for a line matching DISTRIB_ID=Ubuntu in
-     * the file /etc/lsb-release.
-     */
-    fp = fopen("/etc/lsb-release", "r");
-    if (fp != NULL) {
-        while (((line = fget_next_line(fp, &eof))
-                    != NULL) && !eof) {
-            ptr = strstr(line, "DISTRIB_ID");
-            if (ptr != NULL) {
-                fclose(fp);
-                while (ptr != NULL && *ptr != '=') ptr++;
-                if (ptr != NULL && *ptr == '=') ptr++;
-                if (ptr != NULL && *ptr != '\0')
-                    if (!strcasecmp(ptr, "Ubuntu")) return UBUNTU;
-                break;
-            }
-        }
-    }
-
     if (access("/etc/debian_version", F_OK) == 0) return DEBIAN;
 
     return OTHER;
@@ -1909,93 +1579,21 @@ Distribution get_distribution(Options *op)
 } /* get_distribution() */
 
 
-/*
- * check_for_modular_xorg() - run the X binary with the '-version'
- * command line option and extract the version in an attempt to
- * determine if it's part of a modular Xorg release. If the version
- * can't be determined, we assume it's not.
- */
-
-#define OLD_VERSION_FORMAT "(protocol Version %d, revision %d, vendor release %d)"
-#define NEW_VERSION_FORMAT "X Protocol Version %d, Revision %d, Release %d."
-
-int check_for_modular_xorg(Options *op)
-{
-    char *cmd = NULL, *ptr, *data = NULL;
-    int modular_xorg = FALSE;
-    int dummy, release;
-
-    if (!op->utils[XSERVER])
-        goto done;
-
-    cmd = nvstrcat(op->utils[XSERVER], " -version", NULL);
-
-    if (run_command(op, cmd, &data, FALSE, 0, TRUE) ||
-        (data == NULL)) {
-        goto done;
-    }
-
-    /*
-     * Check if this is an XFree86 release that identifies
-     * itself as such in the version string.
-     */
-    if (strstr(data, "XFree86 Version"))
-        goto done;
-
-    /*
-     * Check if this looks like an XFree86 release older
-     * than XFree86 4.3.0.
-     */
-    if ((ptr = strstr(data, "(protocol Version")) != NULL &&
-        sscanf(ptr, OLD_VERSION_FORMAT, &dummy, &dummy, &release) == 3) {
-        goto done;
-    }
-
-    /*
-     * Check if this looks like an XFree86 release between
-     * XFree86 4.2 and 4.5, or an Xorg release.
-     */
-
-    if ((ptr = strstr(data, "X Protocol Version")) != NULL &&
-        sscanf(ptr, NEW_VERSION_FORMAT, &dummy, &dummy, &release) == 3) {
-        modular_xorg = (release >= 7);
-        goto done;
-    }
-
-    /*
-     * If all else fails, check if this is an Xorg release
-     * that identifies itself as such.
-     */
-    if ((ptr = strstr(data, "X Window System Version")) &&
-        sscanf(ptr, "X Window System Version %d.", &release) == 1) {
-        modular_xorg = (release >= 7);
-    }
-
-done:
-    nvfree(data);
-    nvfree(cmd);
-
-    return modular_xorg;
-
-} /* check_for_modular_xorg() */
-
 
 /*
  * check_for_running_x() - running any X server (even with a
  * non-NVIDIA driver) can cause stability problems, so check that
  * there is no X server running.  To do this, scan for any
  * /tmp/.X[n]-lock files, where [n] is the number of the X Display
- * (we'll just check for 0-7). Get the pid contained in this X lock file,
- * this is the pid of the running X server. If any X server is running, 
- * print an error message and return FALSE.  If no X server is running, 
- * return TRUE.
+ * (we'll just check for 0-7).  If any X server is running, print an
+ * error message and return FALSE.  If no X server is running, return
+ * TRUE.
  */
 
 int check_for_running_x(Options *op)
 {
-    char path[14], *buf;
-    char procpath[17]; /* contains /proc/%d, accounts for 32-bit values of pid */
-    int i, pid;
+    char path[14];
+    int i;
 
     /*
      * If we are installing for a non-running kernel *and* we are only
@@ -2010,24 +1608,15 @@ int check_for_running_x(Options *op)
     
     for (i = 0; i < 8; i++) {
         snprintf(path, 14, "/tmp/.X%1d-lock", i);
-        if (read_text_file(path, &buf) == TRUE) {
-            sscanf(buf, "%d", &pid);
-            nvfree(buf);
-            snprintf(procpath, 17, "/proc/%d", pid);
-            if (access(procpath, F_OK) == 0) {
-                ui_log(op, "The file '%s' exists and appears to contain the "
-                           "process ID '%d' of a runnning X server.", path, pid);
-                if (op->no_x_check) {
-                    ui_log(op, "Continuing per the '--no-x-check' option.");
-                } else {
-                    ui_error(op, "You appear to be running an X server; please "
-                                 "exit X before installing.  For further details, "
-                                 "please see the section INSTALLING THE NVIDIA "
-                                 "DRIVER in the README available on the Linux driver "
-                                 "download page at www.nvidia.com.");
-                    return FALSE;
-                }
-            }
+        if (access(path, R_OK) == 0) {
+            ui_log(op, "The file '%s' exists... an X server appears to be "
+                   "running", path);
+            ui_error(op, "You appear to be running an X server; please exit "
+                     "X before installing.  For further details, please see "
+                     "the section INSTALLING THE NVIDIA DRIVER in the README "
+                     "available on the Linux driver download page at "
+                     "www.nvidia.com.");
+            return FALSE;
         }
     }
     
@@ -2036,218 +1625,6 @@ int check_for_running_x(Options *op)
 } /* check_for_running_x() */
 
 
-/*
- * check_for_nvidia_graphics_devices() - check if there are supported
- * NVIDIA graphics devices installed in this system. If one or more
- * supported devices are found, the function returns TRUE, else it prints
- * a warning message and returns FALSE. If legacy devices are detected
- * in the system, a warning message is printed for each one.
- */
-
-static void ignore_libpci_output(char *fmt, ...)
-{
-}
-
-int check_for_nvidia_graphics_devices(Options *op, Package *p)
-{
-    struct pci_access *pacc;
-    struct pci_dev *dev;
-    int i, found_supported_device = FALSE;
-    uint16 class;
-
-    pacc = pci_alloc();
-    if (!pacc) return TRUE;
-
-    pacc->error = ignore_libpci_output;
-    pacc->warning = ignore_libpci_output;
-    pci_init(pacc);
-    if (!pacc->methods) return TRUE;
-
-    pci_scan_bus(pacc);
-
-    for (dev = pacc->devices; dev != NULL; dev = dev->next) {
-        if ((pci_fill_info(dev, PCI_FILL_IDENT) & PCI_FILL_IDENT) &&
-              ((class = pci_read_word(dev, PCI_CLASS_DEVICE)) == PCI_CLASS_DISPLAY_VGA) &&
-              (dev->vendor_id == 0x10de) /* NVIDIA */ &&
-              (dev->device_id >= 0x0020) /* TNT or later */) {
-            /*
-             * First check if this GPU is a "legacy" GPU; if it is, print a
-             * warning message and point the user to the NVIDIA Linux
-             * driver download page for.
-             */
-            int found_legacy_device = FALSE;
-            for (i = 0; i < sizeof(LegacyList) / sizeof(LEGACY_INFO); i++) {
-                if (dev->device_id == LegacyList[i].uiDevId) {
-                    ui_warn(op, "The NVIDIA %s GPU installed in this system is supported "
-                            "through the NVIDIA legacy Linux graphics drivers.  Please "
-                            "visit http://www.nvidia.com/object/unix.html for more "
-                            "information.  The %s NVIDIA Linux graphics driver will "
-                            "ignore this GPU.", LegacyList[i].AdapterString, p->version_string);
-                    found_legacy_device = TRUE;
-                }
-            }
-            if (!found_legacy_device) found_supported_device = TRUE;
-        }
-    }
-
-    pci_cleanup(pacc);
-    if (!pacc->devices) return TRUE;
-
-    if (!found_supported_device) {
-        ui_warn(op, "You do not appear to have an NVIDIA GPU supported by the "
-                 "%s NVIDIA Linux graphics driver installed in this system.  "
-                 "For further details, please see the appendix SUPPORTED "
-                 "NVIDIA GRAPHICS CHIPS in the README available on the Linux "
-                 "driver download page at www.nvidia.com.", p->version_string);
-        return FALSE;
-    }
-
-    return TRUE;
-
-} /* check_for_nvidia_graphics_devices() */
-
-
-/*
- * check_selinux() - check if selinux is available.
- * Sets the variable op->selinux_enabled.
- * Returns TRUE on success, FALSE otherwise.
- */
-int check_selinux(Options *op)
-{
-    int selinux_available = TRUE;
-    
-    if (op->utils[CHCON] == NULL ||
-        op->utils[SELINUX_ENABLED] == NULL || 
-        op->utils[GETENFORCE] == NULL) {
-        selinux_available = FALSE;
-    }
-    
-    switch (op->selinux_option) {
-    case SELINUX_FORCE_YES:
-        if (selinux_available == FALSE) {
-            /* We have set the option --force-selinux=yes but SELinux 
-             * is not available on this system */
-            ui_error(op, "Invalid option '--force-selinux=yes'; "
-                        "SELinux is not available on this system");
-            return FALSE;
-        }
-        op->selinux_enabled = TRUE;
-        break;
-        
-    case SELINUX_FORCE_NO:
-        if (selinux_available == TRUE) {
-            char *data = NULL;
-            int ret = run_command(op, op->utils[GETENFORCE], &data, 
-                                  FALSE, 0, TRUE);
-            
-            if ((ret != 0) || (!data)) {
-                ui_warn(op, "Cannot check the current mode of SELinux; "
-                             "Command getenforce() failed"); 
-            } else if (!strcmp(data, "Enforcing")) {
-                /* We have set the option --force-selinux=no but SELinux 
-                 * is enforced on this system */
-                ui_warn(op, "The option '--force-selinux' has been set to 'no', "
-                            "but SELinux is enforced on this system; "
-                            "The X server may not start correctly ");
-            }
-            nvfree(data);
-        }        
-        op->selinux_enabled = FALSE;
-        break;
-        
-    case SELINUX_DEFAULT:
-        op->selinux_enabled = FALSE;
-        if (selinux_available == TRUE) {
-            int ret = run_command(op, op->utils[SELINUX_ENABLED], NULL, 
-                                  FALSE, 0, TRUE);
-            if (ret == 0) {
-                op->selinux_enabled = TRUE;
-            }
-        }
-        break;
-    }                 
-
-    /* Figure out which chcon type we need if the user didn't supply one. */
-    if (op->selinux_enabled && !op->selinux_chcon_type) {
-        unsigned char foo = 0;
-        char *tmpfile;
-        static const char* chcon_types[] = {
-            "textrel_shlib_t",    /* Shared library with text relocations */
-            "texrel_shlib_t",     /* Obsolete synonym for the above */
-            "shlib_t",            /* Generic shared library */
-            NULL
-        };
-
-        /* Create a temporary file */
-        tmpfile = write_temp_file(op, 1, &foo, S_IRUSR);
-        if (!tmpfile) {
-            ui_warn(op, "Couldn't test chcon.  Assuming shlib_t.");
-            op->selinux_chcon_type = "shlib_t";
-        } else {
-            int i, ret;
-            char *cmd;
-
-            /* Try each chcon command */
-            for (i = 0; chcon_types[i]; i++) {
-                cmd = nvstrcat(op->utils[CHCON], " -t ", chcon_types[i], " ",
-                               tmpfile, NULL);
-                ret = run_command(op, cmd, NULL, FALSE, 0, TRUE);
-                nvfree(cmd);
-
-                if (ret == 0) break;
-            }
-
-            if (!chcon_types[i]) {
-                /* None of them work! */
-                ui_warn(op, "Couldn't find a working chcon argument.  "
-                            "Defaulting to shlib_t.");
-                op->selinux_chcon_type = "shlib_t";
-            } else {
-                op->selinux_chcon_type = chcon_types[i];
-            }
-
-            unlink(tmpfile);
-            nvfree(tmpfile);
-        }
-    }
-
-    if (op->selinux_enabled) {
-        ui_log(op, "Tagging shared libraries with chcon -t %s.",
-               op->selinux_chcon_type);
-    }
-
-    return TRUE;
-} /* check_selinux */
-
-/*
- * run_nvidia_xconfig() - run the `nvidia-xconfig` utility.  Without
- * any options, this will just make sure the X config file uses the
- * NVIDIA driver by default.
- */
-
-int run_nvidia_xconfig(Options *op)
-{
-    int ret, bRet = TRUE;
-    char *data = NULL, *cmd;
-    
-    cmd = find_system_util("nvidia-xconfig");
-    
-    ret = run_command(op, cmd, &data, FALSE, FALSE, TRUE);
-    nvfree(cmd);
-    
-    if (ret != 0) {
-        ui_error(op, "Failed to run nvidia-xconfig:\n%s", data);
-        bRet = FALSE;
-    }
-    
-    nvfree(data);
-
-    return bRet;
-    
-} /* run_nvidia_xconfig() */
-
-
-
 /*
  * nv_format_text_rows() - this function breaks the given string str
  * into some number of rows, where each row is not longer than the
