@@ -136,8 +136,6 @@ typedef struct {
 #define NV_NCURSES_ENTER 10
 #define NV_NCURSES_BACKSPACE 8
 
-#define NV_NCURSES_CTRL(x) ((x) & 0x1f)
-
 
 /*
  * somewhat arbitrary minimum values: if the current window size is
@@ -207,7 +205,7 @@ static void nv_ncurses_do_progress_bar_message(DataStruct *, const char *,
 /* pager functions */
 
 static PagerStruct *nv_ncurses_create_pager(DataStruct *, int, int, int, int,
-                                            TextRows *, const char *, int);
+                                            TextRows *, const char *);
 static void nv_ncurses_pager_update(DataStruct *, PagerStruct *);
 static void nv_ncurses_pager_handle_events(DataStruct *, PagerStruct *, int);
 static void nv_ncurses_destroy_pager(PagerStruct *);
@@ -232,7 +230,7 @@ static void nv_ncurses_free_text_rows(TextRows *);
 static int nv_ncurses_format_print(DataStruct *, RegionStruct *,
                                    int, int, int, int, TextRows *t);
 
-static int nv_ncurses_check_resize(DataStruct *, bool);
+static int nv_ncurses_check_resize(DataStruct *);
 
 
 
@@ -401,7 +399,7 @@ static char *nv_ncurses_get_input(Options *op,
 
     if (!msg) return NULL;
 
-    nv_ncurses_check_resize(d, FALSE);
+    nv_ncurses_check_resize(d);
 
     color = d->use_color ? NV_NCURSES_INPUT_COLOR : A_REVERSE;
 
@@ -524,7 +522,7 @@ static char *nv_ncurses_get_input(Options *op,
         
         /* wait for input */
 
-        if (nv_ncurses_check_resize(d, FALSE)) goto draw_get_input;
+        if (nv_ncurses_check_resize(d)) goto draw_get_input;
         ch = getch();
 
         switch (ch) {
@@ -570,11 +568,6 @@ static char *nv_ncurses_get_input(Options *op,
                 redraw = TRUE;
             }
             break;
-
-        case NV_NCURSES_CTRL('L'):
-            nv_ncurses_check_resize(d, TRUE);
-            goto draw_get_input;
-            break;
         }
         
         /*
@@ -628,7 +621,7 @@ static int nv_ncurses_display_license(Options *op, const char *license)
 {
     DataStruct *d = (DataStruct *) op->ui_priv;
     TextRows *t_pager = NULL;
-    int ch, x, cur = 0;
+    int ch, x;
     int button_width, button_y, accept_x, no_accept_x, accepted;
     PagerStruct *p = NULL;
     char *str;
@@ -638,8 +631,7 @@ static int nv_ncurses_display_license(Options *op, const char *license)
         "and continue with the installation, or select "
         "\"Do Not Accept\" to abort the installation.";
 
-    nv_ncurses_check_resize(d, FALSE);
-    accepted = FALSE;
+    nv_ncurses_check_resize(d);
 
  draw_license:
 
@@ -659,6 +651,7 @@ static int nv_ncurses_display_license(Options *op, const char *license)
     button_y = d->message->h - 2;
     accept_x = (d->message->w - (button_width * 3)) / 2;
     no_accept_x = accept_x + (button_width * 2);
+    accepted = 0;
 
     nv_ncurses_draw_button(d, d->message, accept_x, button_y, button_width,
                            1, "Accept", accepted, FALSE);
@@ -671,7 +664,7 @@ static int nv_ncurses_display_license(Options *op, const char *license)
     t_pager = d->format_text_rows(NULL, license, d->message->w, TRUE);
     p = nv_ncurses_create_pager(d, 1, d->message->h + 2, d->message->w,
                               d->height - d->message->h - 4,
-                              t_pager, "NVIDIA Software License", cur);
+                              t_pager, "NVIDIA Software License");
     refresh();
 
     /* process key strokes */
@@ -679,10 +672,7 @@ static int nv_ncurses_display_license(Options *op, const char *license)
     do {
         /* if a resize occurred, jump back to the top and redraw */
         
-        if (nv_ncurses_check_resize(d, FALSE)) {
-            cur = p->cur;
-            goto draw_license;
-        }
+        if (nv_ncurses_check_resize(d)) goto draw_license;
         ch = getch();
 
         switch (ch) {
@@ -707,12 +697,6 @@ static int nv_ncurses_display_license(Options *op, const char *license)
             refresh();
             break;
         
-        case NV_NCURSES_CTRL('L'):
-            nv_ncurses_check_resize(d, TRUE);
-            cur = p->cur;
-            goto draw_license;
-            break;
-
         default:
             break;
         }
@@ -837,15 +821,8 @@ static void nv_ncurses_message(Options *op, int level, const char *msg)
     do {
         /* if a resize occurred, jump back to the top and redraw */
         
-        if (nv_ncurses_check_resize(d, FALSE)) goto draw_message;
+        if (nv_ncurses_check_resize(d)) goto draw_message;
         ch = getch();
-
-        switch (ch) {
-        case NV_NCURSES_CTRL('L'):
-            nv_ncurses_check_resize(d, TRUE);
-            goto draw_message;
-            break;
-        }
     } while (ch != NV_NCURSES_ENTER);
     
     /* animate the button being pushed down */
@@ -900,8 +877,7 @@ static int nv_ncurses_approve_command_list(Options *op, CommandList *cl,
     TextRows *t_pager = NULL;
     PagerStruct *p = NULL;
     char *str, *question;
-    int button_w, button_y, yes_x, no_x;
-    int len, ch, x, yes, cur = 0;
+    int len, ch, x, yes_x, no_x, yes, button_w, button_y;
 
     /* initialize the question string */
 
@@ -912,8 +888,7 @@ static int nv_ncurses_approve_command_list(Options *op, CommandList *cl,
     
     /* check if the window was resized */
 
-    nv_ncurses_check_resize(d, FALSE);
-    yes = 1;
+    nv_ncurses_check_resize(d);
     
  draw_command_list:
 
@@ -937,6 +912,8 @@ static int nv_ncurses_approve_command_list(Options *op, CommandList *cl,
     yes_x = (d->message->w - button_w*3)/2 + 0;
     no_x  = (d->message->w - button_w*3)/2 + 2*button_w;
 
+    yes = 1;
+    
     nv_ncurses_draw_button(d, d->message, yes_x, button_y,
                            button_w, 1, "Yes", yes, FALSE);
     nv_ncurses_draw_button(d, d->message, no_x, button_y,
@@ -947,7 +924,7 @@ static int nv_ncurses_approve_command_list(Options *op, CommandList *cl,
     t_pager = nv_ncurses_create_command_list_textrows(d, cl, d->message->w);
     p = nv_ncurses_create_pager(d, 1, d->message->h + 2, d->message->w,
                               d->height - d->message->h - 4,
-                              t_pager, "Proposed Commandlist", cur);
+                              t_pager, "Proposed Commandlist");
     refresh();
 
     /* process key strokes */
@@ -955,11 +932,8 @@ static int nv_ncurses_approve_command_list(Options *op, CommandList *cl,
     do {
         /* if a resize occurred, jump back to the top and redraw */
         
-        if (nv_ncurses_check_resize(d, FALSE)) {
-            cur = p->cur;
-            goto draw_command_list;
-        }
-        ch = getch();
+        if (nv_ncurses_check_resize(d)) goto draw_command_list;
+	ch = getch();
         
         switch (ch) {
         case NV_NCURSES_TAB:
@@ -979,13 +953,6 @@ static int nv_ncurses_approve_command_list(Options *op, CommandList *cl,
                                    button_w, 1, "No", !yes, FALSE);
             refresh();
             break;
-
-        case NV_NCURSES_CTRL('L'):
-            nv_ncurses_check_resize(d, TRUE);
-            cur = p->cur;
-            goto draw_command_list;
-            break;
-
         default:
             break;
         }
@@ -1055,8 +1022,7 @@ static int nv_ncurses_yes_no(Options *op, const int def, const char *msg)
 
     /* check if the window was resized */
 
-    nv_ncurses_check_resize(d, FALSE);
-    yes = def;
+    nv_ncurses_check_resize(d);
 
  draw_yes_no:
 
@@ -1087,6 +1053,8 @@ static int nv_ncurses_yes_no(Options *op, const int def, const char *msg)
     y = d->message->h - 2;
     yes_x = (d->message->w - w*3)/2 + 0;
     no_x  = (d->message->w - w*3)/2 + 2*w;
+
+    yes = def;
     
     nv_ncurses_draw_button(d, d->message, yes_x, y, w, h, "Yes", yes,FALSE);
     nv_ncurses_draw_button(d, d->message, no_x, y, w, h, "No", !yes, FALSE);
@@ -1096,8 +1064,8 @@ static int nv_ncurses_yes_no(Options *op, const int def, const char *msg)
     /* process key strokes */
 
     do {
-        if (nv_ncurses_check_resize(d, FALSE)) goto draw_yes_no;
-        ch = getch();
+        if (nv_ncurses_check_resize(d)) goto draw_yes_no;
+	ch = getch();
 
         switch (ch) {
         case NV_NCURSES_TAB:
@@ -1117,12 +1085,6 @@ static int nv_ncurses_yes_no(Options *op, const int def, const char *msg)
                                    "No", !yes, FALSE);
             refresh();
             break;
-
-        case NV_NCURSES_CTRL('L'):
-            nv_ncurses_check_resize(d, TRUE);
-            goto draw_yes_no;
-            break;
-
         default:
             break;
         }
@@ -1166,7 +1128,7 @@ static void nv_ncurses_status_begin(Options *op,
 {
     DataStruct *d = (DataStruct *) op->ui_priv;
    
-    nv_ncurses_check_resize(d, FALSE);
+    nv_ncurses_check_resize(d);
 
     /* cache the progress bar title */
 
@@ -1182,7 +1144,7 @@ static void nv_ncurses_status_begin(Options *op,
                                        d->message->w);
 
     refresh();
-
+    
 } /* nv_ncurses_status_begin() */
 
 
@@ -1195,7 +1157,7 @@ static void nv_ncurses_status_begin(Options *op,
 static void nv_ncurses_status_update(Options *op, const float percent,
                                      const char *msg)
 {
-    int i, n, h, ch;
+    int i, n, h;
     int p[4];
     char v[4];
     DataStruct *d = (DataStruct *) op->ui_priv;
@@ -1205,32 +1167,11 @@ static void nv_ncurses_status_update(Options *op, const float percent,
      * redraw the entire progress bar region.
      */
 
-    if (nv_ncurses_check_resize(d, FALSE) || !d->message) {
+    if (nv_ncurses_check_resize(d) || !d->message) {
         if (d->message) nv_ncurses_destroy_region(d->message);
         nv_ncurses_do_progress_bar_region(d);
     }
-
-    /* temporarily set getch() to non-blocking mode */
-
-    nodelay(stdscr, TRUE);
-
-    while ((ch = getch()) != ERR) {
-        /*
-         * if the user explicitely requested that the screen be
-         * redrawn by pressing CTRL-L, then also redraw the entire
-         * progress bar egion.
-         */
-        if (ch == NV_NCURSES_CTRL('L')) {
-            nv_ncurses_check_resize(d, TRUE);
-            if (d->message) nv_ncurses_destroy_region(d->message);
-            nv_ncurses_do_progress_bar_region(d);
-        }
-    }
-
-    /* set getch() back to blocking mode */
-
-    nodelay(stdscr, FALSE);
-
+    
     /* compute the percentage */
 
     n = ((int) (percent * (float) (d->message->w - 2)));
@@ -1297,7 +1238,7 @@ static void nv_ncurses_status_end(Options *op, const char *msg)
      * redraw the entire progress bar region.
      */
 
-    if (nv_ncurses_check_resize(d, FALSE) || !d->message) {
+    if (nv_ncurses_check_resize(d) || !d->message) {
         if (d->message) nv_ncurses_destroy_region(d->message);
         nv_ncurses_do_progress_bar_region(d);
     }
@@ -1769,14 +1710,12 @@ static void nv_ncurses_do_progress_bar_message(DataStruct *d, const char *str,
  *  w      : width of the pager
  *  h      : height of the pager
  *  t      : TextRows to be displayed
- *  label  : string to be displayed in the status bar 
- *  cur    : initial current line of the pager
+ *  label  : string to be displayed in the status bar.
  */
 
 static PagerStruct *nv_ncurses_create_pager(DataStruct *d,
                                             int x, int y, int w, int h,
-                                            TextRows *t, const char *label,
-                                            int cur)
+                                            TextRows *t, const char *label)
 {
     PagerStruct *p = (PagerStruct *) malloc(sizeof(PagerStruct));
     
@@ -1784,7 +1723,7 @@ static PagerStruct *nv_ncurses_create_pager(DataStruct *d,
     p->region = nv_ncurses_create_region(d, x, y, w, h, A_NORMAL, A_NORMAL);
     p->label = label;
     
-    p->cur = cur;
+    p->cur = 0;
     
     p->page = h - 2;
 
@@ -1869,10 +1808,9 @@ static void nv_ncurses_pager_update(DataStruct *d, PagerStruct *p)
 static void nv_ncurses_pager_handle_events(DataStruct *d,
                                            PagerStruct *p, int ch)
 {
-    int n;
-    
+    int n = p->t->n - (p->region->h - 1);
+
     if (!p) return;
-    n = p->t->n - (p->region->h - 1);
 
     switch (ch) {
     case KEY_UP:
@@ -2153,22 +2091,20 @@ static int nv_ncurses_format_print(DataStruct *d, RegionStruct *region,
  * clear everything, update our cached dimensions, and recreate the
  * header and footer.
  *
- * XXX we could catch the SIGWINCH (window resize) signal, but that's
+ * XXX we could catch the SIGREGIONCH signal, but that's
  * asynchronous... it's safer to only attempt to handle a resize when
  * we know we can.
  */
 
-static int nv_ncurses_check_resize(DataStruct *d, bool force)
+static int nv_ncurses_check_resize(DataStruct *d)
 {
     int x, y;
 
     getmaxyx(stdscr, y, x);
 
-    if (!force) {
-        if ((x == d->width) && (y == d->height)) {
-            /* no resize detected... just return */
-            return FALSE;
-        }
+    if ((x == d->width) && (y == d->height)) {
+        /* no resize detected... just return */
+        return FALSE;
     }
 
     /* we have been resized */
