@@ -49,15 +49,6 @@ typedef enum {
     MAX_SYSTEM_UTILS
 } SystemUtils;
 
-typedef enum {
-    CHCON = MAX_SYSTEM_UTILS,
-    SELINUX_ENABLED,
-    GETENFORCE,
-    PKG_CONFIG,
-    XSERVER,
-    MAX_SYSTEM_OPTIONAL_UTILS
-} SystemOptionalUtils;
-
 /*
  * Enumerated type, listing each of the module utilities we'll need.
  * Keep this enum in sync with the needed_utils string array in
@@ -65,7 +56,7 @@ typedef enum {
  */
 
 typedef enum {
-    INSMOD = MAX_SYSTEM_OPTIONAL_UTILS,
+    INSMOD = MAX_SYSTEM_UTILS,
     MODPROBE,
     RMMOD,
     LSMOD,
@@ -83,15 +74,12 @@ typedef enum {
     SUSE,
     UNITED_LINUX,
     DEBIAN,
-    UBUNTU,
-    GENTOO,
     OTHER
 } Distribution;
 
 
-typedef unsigned int   uint32;
-typedef unsigned short uint16;
-typedef unsigned char  uint8;
+typedef unsigned int uint32;
+typedef unsigned char uint8;
 
 
 
@@ -126,42 +114,15 @@ typedef struct __options {
     int no_backup;
     int no_network;
     int kernel_module_only;
-    int no_kernel_module;
     int no_abi_note;
     int no_rpms;
     int no_recursion;
-    int run_nvidia_xconfig;
-    int selinux_option;
-    int selinux_enabled;
-    int sigwinch_workaround;
-    int no_x_check;
 
+    char *xfree86_prefix;
     char *opengl_prefix;
-    char *opengl_libdir;
-    char *opengl_incdir;
-
-    char *x_prefix;
-    char *x_libdir;
-    char *x_moddir;
-    char *x_module_path;
-    char *x_library_path;
-
-    char *compat32_chroot;
     char *compat32_prefix;
-    char *compat32_libdir;
-
-    char *utility_prefix;
-    char *utility_libdir;
-    char *utility_bindir;
     char *installer_prefix;
-
-    char *dot_desktopdir;
-
-    char *documentation_prefix;
-    char *documentation_docdir;
-    char *documentation_mandir;
-
-    int modular_xorg;
+    char *utility_prefix;
 
     char *kernel_source_path;
     char *kernel_output_path;
@@ -180,7 +141,6 @@ typedef struct __options {
     char *kernel_name;
     char *rpm_file_list;
     char *precompiled_kernel_interfaces_path;
-    const char *selinux_chcon_type;
 
     Distribution distro;
 
@@ -280,99 +240,73 @@ typedef struct {
 
 /* file types */
 
-#define FILE_TYPE_MASK               0x00ffffff
+#define FILE_TYPE_MASK              0x0000ffff
 
-#define FILE_TYPE_KERNEL_MODULE_SRC  0x00000001
-#define FILE_TYPE_KERNEL_MODULE_CMD  0x00000002
-#define FILE_TYPE_OPENGL_HEADER      0x00000004
-#define FILE_TYPE_OPENGL_LIB         0x00000008
-#define FILE_TYPE_XLIB_STATIC_LIB    0x00000010
-#define FILE_TYPE_XLIB_SHARED_LIB    0x00000020
-#define FILE_TYPE_DOCUMENTATION      0x00000040
-#define FILE_TYPE_OPENGL_SYMLINK     0x00000080
-#define FILE_TYPE_XLIB_SYMLINK       0x00000100
-#define FILE_TYPE_KERNEL_MODULE      0x00000200
-#define FILE_TYPE_INSTALLER_BINARY   0x00000400
-#define FILE_TYPE_UTILITY_BINARY     0x00000800
-#define FILE_TYPE_LIBGL_LA           0x00001000
-#define FILE_TYPE_TLS_LIB            0x00002000
-#define FILE_TYPE_TLS_SYMLINK        0x00004000
-#define FILE_TYPE_UTILITY_LIB        0x00008000
-#define FILE_TYPE_DOT_DESKTOP        0x00010000
-#define FILE_TYPE_UTILITY_SYMLINK    0x00020000
-#define FILE_TYPE_XMODULE_SHARED_LIB 0x00040000
-#define FILE_TYPE_XMODULE_SYMLINK    0x00080000
-#define FILE_TYPE_MANPAGE            0x00100000
+#define FILE_TYPE_KERNEL_MODULE_SRC 0x00000001
+#define FILE_TYPE_KERNEL_MODULE_CMD 0x00000002
+#define FILE_TYPE_OPENGL_HEADER     0x00000004
+#define FILE_TYPE_OPENGL_LIB        0x00000008
+#define FILE_TYPE_XFREE86_LIB       0x00000010
+#define FILE_TYPE_DOCUMENTATION     0x00000020
+#define FILE_TYPE_OPENGL_SYMLINK    0x00000040
+#define FILE_TYPE_XFREE86_SYMLINK   0x00000080
+#define FILE_TYPE_KERNEL_MODULE     0x00000100
+#define FILE_TYPE_INSTALLER_BINARY  0x00000200
+#define FILE_TYPE_UTILITY_BINARY    0x00000400
+#define FILE_TYPE_LIBGL_LA          0x00000800
+#define FILE_TYPE_TLS_LIB           0x00001000
+#define FILE_TYPE_TLS_SYMLINK       0x00002000
 
 /* file class: this is used to distinguish OpenGL libraries */
 
-#define FILE_CLASS_MASK              0xff000000
+#define FILE_CLASS_MASK             0xffff0000
 
-#define FILE_CLASS_NEW_TLS           0x01000000
-#define FILE_CLASS_CLASSIC_TLS       0x02000000
-#define FILE_CLASS_NATIVE            0x04000000
-#define FILE_CLASS_COMPAT32          0x08000000
+#define FILE_CLASS_NEW_TLS          0x00010000
+#define FILE_CLASS_CLASSIC_TLS      0x00020000
+#define FILE_CLASS_NATIVE           0x00040000
+#define FILE_CLASS_COMPAT32         0x00080000
 
-#define FILE_TYPE_XLIB_LIB         (FILE_TYPE_XLIB_STATIC_LIB | \
-                                    FILE_TYPE_XLIB_SHARED_LIB)
 
-#define FILE_TYPE_XMODULE_LIB      (FILE_TYPE_XMODULE_SHARED_LIB)
+#define FILE_TYPE_INSTALLABLE_FILE (FILE_TYPE_OPENGL_LIB       | \
+                                    FILE_TYPE_XFREE86_LIB      | \
+                                    FILE_TYPE_TLS_LIB          | \
+                                    FILE_TYPE_DOCUMENTATION    | \
+                                    FILE_TYPE_OPENGL_HEADER    | \
+                                    FILE_TYPE_KERNEL_MODULE    | \
+                                    FILE_TYPE_INSTALLER_BINARY | \
+                                    FILE_TYPE_UTILITY_BINARY   | \
+                                    FILE_TYPE_LIBGL_LA)
 
-#define FILE_TYPE_INSTALLABLE_FILE (FILE_TYPE_OPENGL_LIB         | \
-                                    FILE_TYPE_XLIB_LIB           | \
-                                    FILE_TYPE_TLS_LIB            | \
-                                    FILE_TYPE_UTILITY_LIB        | \
-                                    FILE_TYPE_DOCUMENTATION      | \
-                                    FILE_TYPE_MANPAGE            | \
-                                    FILE_TYPE_OPENGL_HEADER      | \
-                                    FILE_TYPE_KERNEL_MODULE      | \
-                                    FILE_TYPE_INSTALLER_BINARY   | \
-                                    FILE_TYPE_UTILITY_BINARY     | \
-                                    FILE_TYPE_LIBGL_LA           | \
-                                    FILE_TYPE_XMODULE_LIB        | \
-                                    FILE_TYPE_DOT_DESKTOP)
-
-#define FILE_TYPE_HAVE_PATH        (FILE_TYPE_XMODULE_LIB        | \
-                                    FILE_TYPE_XMODULE_SYMLINK    | \
-                                    FILE_TYPE_MANPAGE            | \
-                                    FILE_TYPE_OPENGL_HEADER      | \
-                                    FILE_TYPE_TLS_LIB            | \
-                                    FILE_TYPE_TLS_SYMLINK        | \
-                                    FILE_TYPE_DOT_DESKTOP        | \
+#define FILE_TYPE_HAVE_PATH        (FILE_TYPE_OPENGL_LIB       | \
+                                    FILE_TYPE_OPENGL_SYMLINK   | \
+                                    FILE_TYPE_LIBGL_LA         | \
+                                    FILE_TYPE_XFREE86_LIB      | \
+                                    FILE_TYPE_XFREE86_SYMLINK  | \
+                                    FILE_TYPE_TLS_LIB          | \
+                                    FILE_TYPE_TLS_SYMLINK      | \
                                     FILE_TYPE_DOCUMENTATION)
 
-#define FILE_TYPE_HAVE_ARCH        (FILE_TYPE_OPENGL_LIB         | \
-                                    FILE_TYPE_OPENGL_SYMLINK     | \
-                                    FILE_TYPE_LIBGL_LA           | \
-                                    FILE_TYPE_TLS_LIB            | \
+#define FILE_TYPE_HAVE_ARCH        (FILE_TYPE_OPENGL_LIB       | \
+                                    FILE_TYPE_OPENGL_SYMLINK   | \
+                                    FILE_TYPE_LIBGL_LA         | \
+                                    FILE_TYPE_TLS_LIB          | \
                                     FILE_TYPE_TLS_SYMLINK)
 
-#define FILE_TYPE_HAVE_CLASS       (FILE_TYPE_TLS_LIB            | \
+#define FILE_TYPE_HAVE_CLASS       (FILE_TYPE_TLS_LIB          | \
                                     FILE_TYPE_TLS_SYMLINK)
 
-#define FILE_TYPE_SYMLINK          (FILE_TYPE_OPENGL_SYMLINK     | \
-                                    FILE_TYPE_XLIB_SYMLINK       | \
-                                    FILE_TYPE_TLS_SYMLINK        | \
-                                    FILE_TYPE_XMODULE_SYMLINK    | \
-                                    FILE_TYPE_UTILITY_SYMLINK)
+#define FILE_TYPE_SYMLINK          (FILE_TYPE_OPENGL_SYMLINK   | \
+                                    FILE_TYPE_XFREE86_SYMLINK  | \
+                                    FILE_TYPE_TLS_SYMLINK)
 
-#define FILE_TYPE_RTLD_CHECKED     (FILE_TYPE_OPENGL_LIB         | \
+#define FILE_TYPE_RTLD_CHECKED     (FILE_TYPE_OPENGL_LIB       | \
                                     FILE_TYPE_TLS_LIB)
 
-#define FILE_TYPE_SHARED_LIB       (FILE_TYPE_OPENGL_LIB         | \
-                                    FILE_TYPE_XLIB_SHARED_LIB    | \
-                                    FILE_TYPE_TLS_LIB            | \
-                                    FILE_TYPE_XMODULE_SHARED_LIB | \
-                                    FILE_TYPE_UTILITY_LIB)
 
 #define TLS_LIB_TYPE_FORCED         0x0001
 #define TLS_LIB_NEW_TLS             0x0002
 #define TLS_LIB_CLASSIC_TLS         0x0004
 
-#define SELINUX_DEFAULT             0x0000
-#define SELINUX_FORCE_YES           0x0001
-#define SELINUX_FORCE_NO            0x0002
-
 #define FORCE_CLASSIC_TLS          (TLS_LIB_CLASSIC_TLS | TLS_LIB_TYPE_FORCED)
 #define FORCE_NEW_TLS              (TLS_LIB_NEW_TLS | TLS_LIB_TYPE_FORCED)
 
@@ -380,65 +314,21 @@ typedef struct {
 
 #define PRECOMPILED_KERNEL_INTERFACE_FILENAME "precompiled-nv-linux.o"
 
-
-/*
- * These are the default installation prefixes and the default
- * paths relative to the prefixes. Some of the defaults are
- * overriden on some distributions or when the new modular Xorg
- * is detected, all prefixes/paths can be overriden from the
- * command line.
- */
-#define DEFAULT_OPENGL_PREFIX           "/usr"
-#define DEFAULT_X_PREFIX                "/usr/X11R6"
-#define DEFAULT_UTILITY_PREFIX          "/usr"
-#define DEFAULT_DOCUMENTATION_PREFIX    "/usr"
-
-#define DEFAULT_LIBDIR                  "lib"
-#define DEFAULT_64BIT_LIBDIR            "lib64"
-#define DEFAULT_BINDIR                  "bin"
-#define DEFAULT_INCDIR                  "include"
-#define DEFAULT_X_MODULEDIR             "modules"
-#define DEFAULT_DOT_DESKTOPDIR          "share/applications"
-#define DEFAULT_DOCDIR                  "share/doc"
-#define DEFAULT_MANDIR                  "share/man"
-
-/*
- * As of Xorg 7.x, X components need not be installed relative
- * to a special top-level directory, they can be integrated
- * more tightly with the rest of the system. The system must be
- * queried for the installation paths, but in the event that
- * this fails, the fallbacks below are chosen.
- */
-#define XORG7_DEFAULT_X_PREFIX          "/usr"
-#define XORG7_DEFAULT_X_MODULEDIR       "xorg/modules"
-
-/*
- * Debian GNU/Linux for x86-64 installs 32-bit compatibility
- * libraries relative to a chroot-like top-level directory; the
- * prefix below is prepended to the full paths.
- */
-#define DEBIAN_DEFAULT_COMPAT32_CHROOT  "/emul/ia32-linux"
-
-/*
- * Debian GNU/Linux and Ubuntu do not follow the lib64 library
- * path naming convention used by other distributors. 64-bit
- * libraries are placed under ../lib.
- */
-#define DEBIAN_DEFAULT_64BIT_LIBDIR     "lib"
-
-/*
- * Ubuntu GNU/Linux and Gentoo Linux do not follow the "lib"
- * library path naming convention used for 32-bit compatibility
- * libraries by other distributors. These libraries are
- * placed under ../lib32.
- */
-#define UBUNTU_DEFAULT_COMPAT32_LIBDIR  "lib32"
+#define DEFAULT_XFREE86_INSTALLATION_PREFIX "/usr/X11R6"
+#define DEFAULT_OPENGL_INSTALLATION_PREFIX "/usr"
+#define DEFAULT_INSTALLER_INSTALLATION_PREFIX "/usr"
+#define DEFAULT_UTILITY_INSTALLATION_PREFIX "/usr"
+#define DEBIAN_COMPAT32_INSTALLATION_PREFIX "/emul/ia32-linux"
 
 
 #define DEFAULT_PROC_MOUNT_POINT "/proc"
 
 #define DEFAULT_FTP_SITE "ftp://download.nvidia.com"
 
+#define OPENGL_HEADER_DST_PATH "include/GL"
+#define INSTALLER_BINARY_DST_PATH "bin"
+#define UTILITY_BINARY_DST_PATH "bin"
+
 #define LICENSE_FILE "LICENSE"
 
 #define DEFAULT_LOG_FILE_NAME "/var/log/nvidia-installer.log"
