@@ -54,20 +54,20 @@
  * bytes, and build a uint32.
  */
 
-static uint32 decode_uint32(char *buf)
+static uint32 decode_uint32(uint8 *buf)
 {
     uint32 ret = 0;
 
-    ret += (((uint32) buf[3]) & 0xff);
+    ret += (uint32) buf[3];
     ret <<= 8;
 
-    ret += (((uint32) buf[2]) & 0xff);
+    ret += (uint32) buf[2];
     ret <<= 8;
 
-    ret += (((uint32) buf[1]) & 0xff);
+    ret += (uint32) buf[1];
     ret <<= 8;
 
-    ret += (((uint32) buf[0]) & 0xff);
+    ret += (uint32) buf[0];
     ret <<= 0;
 
     return ret;
@@ -158,7 +158,7 @@ PrecompiledInfo *precompiled_unpack(Options *op,
                                     const int package_patch)
 {
     int dst_fd, fd, offset, len = 0;
-    char *buf, *dst;
+    uint8 *buf, *dst;
     uint32 crc, major, minor, patch, val, size;
     char *description, *proc_version_string;
     struct stat stat_buf;
